/***************************************************************************************************************************************************************
 *
 * font end-to-end tests
 *
 **************************************************************************************************************************************************************/


const { Options } = require('../../src/Options.js');
const Spawn = require('child_process').spawnSync;
const { inspect } = require('util');
const path = require('path');


beforeEach(() => {
	const DEFAULTS = {
		font: 'block',
		align: 'left',
		colors: [],
		background: 'transparent',
		letterSpacing: 1,
		lineHeight: 1,
		space: true,
		maxLength: 0,
		gradient: false,
		independentGradient: false,
		transitionGradient: false,
	};

	Options.set = DEFAULTS;
});


const supportedCharacters = `abcdefghijklmnopqrstuvwxyz0123456789!?.+-_=@#$%&()/:;,'"`;


test(`Fonts - Will output all characters for font blocks`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'  █████╗  ██████╗   ██████╗ ██████╗  ███████╗ ███████╗  ██████╗  ██╗  ██╗ ██╗ \n' +
		' ██╔══██╗ ██╔══██╗ ██╔════╝ ██╔══██╗ ██╔════╝ ██╔════╝ ██╔════╝  ██║  ██║ ██║ \n' +
		' ███████║ ██████╔╝ ██║      ██║  ██║ █████╗   █████╗   ██║  ███╗ ███████║ ██║ \n' +
		' ██╔══██║ ██╔══██╗ ██║      ██║  ██║ ██╔══╝   ██╔══╝   ██║   ██║ ██╔══██║ ██║ \n' +
		' ██║  ██║ ██████╔╝ ╚██████╗ ██████╔╝ ███████╗ ██║      ╚██████╔╝ ██║  ██║ ██║ \n' +
		' ╚═╝  ╚═╝ ╚═════╝   ╚═════╝ ╚═════╝  ╚══════╝ ╚═╝       ╚═════╝  ╚═╝  ╚═╝ ╚═╝ \n' +
		'\n' +
		'      ██╗ ██╗  ██╗ ██╗      ███╗   ███╗ ███╗   ██╗  ██████╗  ██████╗   ██████╗  \n' +
		'      ██║ ██║ ██╔╝ ██║      ████╗ ████║ ████╗  ██║ ██╔═══██╗ ██╔══██╗ ██╔═══██╗ \n' +
		'      ██║ █████╔╝  ██║      ██╔████╔██║ ██╔██╗ ██║ ██║   ██║ ██████╔╝ ██║   ██║ \n' +
		' ██   ██║ ██╔═██╗  ██║      ██║╚██╔╝██║ ██║╚██╗██║ ██║   ██║ ██╔═══╝  ██║▄▄ ██║ \n' +
		' ╚█████╔╝ ██║  ██╗ ███████╗ ██║ ╚═╝ ██║ ██║ ╚████║ ╚██████╔╝ ██║      ╚██████╔╝ \n' +
		'  ╚════╝  ╚═╝  ╚═╝ ╚══════╝ ╚═╝     ╚═╝ ╚═╝  ╚═══╝  ╚═════╝  ╚═╝       ╚══▀▀═╝  \n' +
		'\n' +
		' ██████╗  ███████╗ ████████╗ ██╗   ██╗ ██╗   ██╗ ██╗    ██╗ ██╗  ██╗ ██╗   ██╗ \n' +
		' ██╔══██╗ ██╔════╝ ╚══██╔══╝ ██║   ██║ ██║   ██║ ██║    ██║ ╚██╗██╔╝ ╚██╗ ██╔╝ \n' +
		' ██████╔╝ ███████╗    ██║    ██║   ██║ ██║   ██║ ██║ █╗ ██║  ╚███╔╝   ╚████╔╝  \n' +
		' ██╔══██╗ ╚════██║    ██║    ██║   ██║ ╚██╗ ██╔╝ ██║███╗██║  ██╔██╗    ╚██╔╝   \n' +
		' ██║  ██║ ███████║    ██║    ╚██████╔╝  ╚████╔╝  ╚███╔███╔╝ ██╔╝ ██╗    ██║    \n' +
		' ╚═╝  ╚═╝ ╚══════╝    ╚═╝     ╚═════╝    ╚═══╝    ╚══╝╚══╝  ╚═╝  ╚═╝    ╚═╝    \n' +
		'\n' +
		' ███████╗  ██████╗   ██╗ ██████╗  ██████╗  ██╗  ██╗ ███████╗  ██████╗  ███████╗ \n' +
		' ╚══███╔╝ ██╔═████╗ ███║ ╚════██╗ ╚════██╗ ██║  ██║ ██╔════╝ ██╔════╝  ╚════██║ \n' +
		'   ███╔╝  ██║██╔██║ ╚██║  █████╔╝  █████╔╝ ███████║ ███████╗ ███████╗      ██╔╝ \n' +
		'  ███╔╝   ████╔╝██║  ██║ ██╔═══╝   ╚═══██╗ ╚════██║ ╚════██║ ██╔═══██╗    ██╔╝  \n' +
		' ███████╗ ╚██████╔╝  ██║ ███████╗ ██████╔╝      ██║ ███████║ ╚██████╔╝    ██║   \n' +
		' ╚══════╝  ╚═════╝   ╚═╝ ╚══════╝ ╚═════╝       ╚═╝ ╚══════╝  ╚═════╝     ╚═╝   \n' +
		'\n' +
		'  █████╗   █████╗  ██╗ ██████╗                                       ██████╗  \n' +
		' ██╔══██╗ ██╔══██╗ ██║ ╚════██╗       ██╗                   ██████╗ ██╔═══██╗ \n' +
		' ╚█████╔╝ ╚██████║ ██║   ▄███╔╝     ██████╗ █████╗          ╚═════╝ ██║██╗██║ \n' +
		' ██╔══██╗  ╚═══██║ ╚═╝   ▀▀══╝       ╚██╔═╝ ╚════╝          ██████╗ ██║██║██║ \n' +
		' ╚█████╔╝  █████╔╝ ██╗   ██╗    ██╗   ╚═╝          ███████╗ ╚═════╝ ╚█║████╔╝ \n' +
		'  ╚════╝   ╚════╝  ╚═╝   ╚═╝    ╚═╝                ╚══════╝          ╚╝╚═══╝  \n' +
		'\n' +
		'  ██╗ ██╗  ▄▄███▄▄· ██╗ ██╗    ██╗     ██╗ ██╗      ██╗             █╗  █╗█╗  \n' +
		' ████████╗ ██╔════╝ ╚═╝██╔╝    ██║    ██╔╝ ╚██╗    ██╔╝ ██╗         ╚╝  ╚╝╚╝  \n' +
		' ╚██╔═██╔╝ ███████╗   ██╔╝  ████████╗ ██║   ██║   ██╔╝  ╚═╝ ██╗               \n' +
		' ████████╗ ╚════██║  ██╔╝   ██╔═██╔═╝ ██║   ██║  ██╔╝   ██╗ ╚═╝               \n' +
		' ╚██╔═██╔╝ ███████║ ██╔╝██╗ ██████║   ╚██╗ ██╔╝ ██╔╝    ╚═╝ ▄█╗ ▄█╗           \n' +
		'  ╚═╝ ╚═╝  ╚═▀▀▀══╝ ╚═╝ ╚═╝ ╚═════╝    ╚═╝ ╚═╝  ╚═╝         ▀═╝ ▀═╝           \n' +
		'\n\n';


	expect( output.stderr ).toBe( '' );
	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
});


test(`Fonts - Will output all characters for font blocks in all colors`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-c', 'red,blue' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'  \x1B[38;2;255;0;0m█████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m  \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m  \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m  \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m  ██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \n \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔════╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔════╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔════╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔════╝ \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m  ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \n \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║     \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m  ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m█████\x1B[39m\x1B[38;2;0;0;255m╗  \x1B[39m \x1B[38;2;255;0;0m█████\x1B[39m\x1B[38;2;0;0;255m╗  \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m  ███\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \n \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║     \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m  ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔══╝  \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔══╝  \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \n \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m  ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║     \x1B[39m \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m  ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \n \x1B[38;2;0;0;255m╚═╝  ╚═╝\x1B[39m \x1B[38;2;0;0;255m╚═════╝ \x1B[39m \x1B[38;2;0;0;255m ╚═════╝\x1B[39m \x1B[38;2;0;0;255m╚═════╝ \x1B[39m \x1B[38;2;0;0;255m╚══════╝\x1B[39m \x1B[38;2;0;0;255m╚═╝     \x1B[39m \x1B[38;2;0;0;255m ╚═════╝ \x1B[39m \x1B[38;2;0;0;255m╚═╝  ╚═╝\x1B[39m \x1B[38;2;0;0;255m╚═╝\x1B[39m \n\n \x1B[38;2;255;0;0m     ██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m  ██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗     \x1B[39m \x1B[38;2;255;0;0m███\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m   ███\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m███\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m  \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m  \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m \n \x1B[38;2;255;0;0m     ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m ██\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║     \x1B[39m \x1B[38;2;255;0;0m████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m ████\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m  ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔═══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔═══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \n \x1B[38;2;255;0;0m     ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m█████\x1B[39m\x1B[38;2;0;0;255m╔╝ \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║     \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔\x1B[39m\x1B[38;2;255;0;0m████\x1B[39m\x1B[38;2;0;0;255m╔\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \n \x1B[38;2;255;0;0m██   ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔═\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║     \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║╚\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║╚\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔═══╝ \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m▄▄ ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \n \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m█████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m  ██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║ ╚═╝\x1B[39m\x1B[38;2;255;0;0m ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║ ╚\x1B[39m\x1B[38;2;255;0;0m████\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║     \x1B[39m \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \n \x1B[38;2;0;0;255m ╚════╝ \x1B[39m \x1B[38;2;0;0;255m╚═╝  ╚═╝\x1B[39m \x1B[38;2;0;0;255m╚══════╝\x1B[39m \x1B[38;2;0;0;255m╚═╝     ╚═╝\x1B[39m \x1B[38;2;0;0;255m╚═╝  ╚═══╝\x1B[39m \x1B[38;2;0;0;255m ╚═════╝ \x1B[39m \x1B[38;2;0;0;255m╚═╝     \x1B[39m \x1B[38;2;0;0;255m ╚══\x1B[39m\x1B[38;2;255;0;0m▀▀\x1B[39m\x1B[38;2;0;0;255m═╝ \x1B[39m \n\n \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m████████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗    \x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m  ██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \n \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔════╝\x1B[39m \x1B[38;2;0;0;255m╚══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔══╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║    \x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m ██\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \n \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m║   \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m █\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;0;0;255m ╚\x1B[39m\x1B[38;2;255;0;0m███\x1B[39m\x1B[38;2;0;0;255m╔╝ \x1B[39m \x1B[38;2;0;0;255m ╚\x1B[39m\x1B[38;2;255;0;0m████\x1B[39m\x1B[38;2;0;0;255m╔╝ \x1B[39m \n \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;0;0;255m╚════\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m║   \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m ██\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m███\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m  \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m \x1B[38;2;0;0;255m  ╚\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔╝  \x1B[39m \n \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m  ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m║   \x1B[39m \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;0;0;255m ╚\x1B[39m\x1B[38;2;255;0;0m████\x1B[39m\x1B[38;2;0;0;255m╔╝ \x1B[39m \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m███\x1B[39m\x1B[38;2;0;0;255m╔\x1B[39m\x1B[38;2;255;0;0m███\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m\x1B[38;2;255;0;0m ██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m║   \x1B[39m \n \x1B[38;2;0;0;255m╚═╝  ╚═╝\x1B[39m \x1B[38;2;0;0;255m╚══════╝\x1B[39m \x1B[38;2;0;0;255m   ╚═╝   \x1B[39m \x1B[38;2;0;0;255m ╚═════╝ \x1B[39m \x1B[38;2;0;0;255m  ╚═══╝  \x1B[39m \x1B[38;2;0;0;255m ╚══╝╚══╝ \x1B[39m \x1B[38;2;0;0;255m╚═╝  ╚═╝\x1B[39m \x1B[38;2;0;0;255m   ╚═╝   \x1B[39m \n\n \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m  \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m  \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m  ██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m  \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \n \x1B[38;2;0;0;255m╚══\x1B[39m\x1B[38;2;255;0;0m███\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔═\x1B[39m\x1B[38;2;255;0;0m████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m███\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;0;0;255m╚════\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;0;0;255m╚════\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m  ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔════╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔════╝ \x1B[39m \x1B[38;2;0;0;255m╚════\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \n \x1B[38;2;255;0;0m  ███\x1B[39m\x1B[38;2;0;0;255m╔╝ \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m  \x1B[38;2;255;0;0m█████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m  \x1B[38;2;255;0;0m█████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m \x1B[38;2;255;0;0m    ██\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \n  \x1B[38;2;255;0;0m███\x1B[39m\x1B[38;2;0;0;255m╔╝  \x1B[39m \x1B[38;2;255;0;0m████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m  \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔═══╝ \x1B[39m \x1B[38;2;0;0;255m ╚═══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;0;0;255m╚════\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;0;0;255m╚════\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔═══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m╔╝ \x1B[39m \n \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m  \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m     ██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m║  \x1B[39m \n \x1B[38;2;0;0;255m╚══════╝\x1B[39m \x1B[38;2;0;0;255m ╚═════╝ \x1B[39m \x1B[38;2;0;0;255m ╚═╝\x1B[39m \x1B[38;2;0;0;255m╚══════╝\x1B[39m \x1B[38;2;0;0;255m╚═════╝ \x1B[39m \x1B[38;2;0;0;255m     ╚═╝\x1B[39m \x1B[38;2;0;0;255m╚══════╝\x1B[39m \x1B[38;2;0;0;255m ╚═════╝ \x1B[39m \x1B[38;2;0;0;255m   ╚═╝  \x1B[39m \n\n  \x1B[38;2;255;0;0m█████\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m  \x1B[38;2;255;0;0m█████\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m                                      \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m \n \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;0;0;255m╚════\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m     \x1B[38;2;255;0;0m  ██\x1B[39m\x1B[38;2;0;0;255m╗  \x1B[39m                 \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔═══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \n \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m█████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m  ▄███\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m     \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m█████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m          \x1B[38;2;0;0;255m╚═════╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \n \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;0;0;255m ╚═══\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;0;0;255m╚═╝\x1B[39m \x1B[38;2;255;0;0m  ▀▀\x1B[39m\x1B[38;2;0;0;255m══╝ \x1B[39m     \x1B[38;2;0;0;255m ╚\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔═╝\x1B[39m \x1B[38;2;0;0;255m╚════╝\x1B[39m          \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \n \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m█████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m  \x1B[38;2;255;0;0m█████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m  ██\x1B[39m\x1B[38;2;0;0;255m╗   \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;0;0;255m  ╚═╝  \x1B[39m        \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;0;0;255m╚═════╝\x1B[39m \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m█\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m\x1B[38;2;255;0;0m████\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \n \x1B[38;2;0;0;255m ╚════╝ \x1B[39m \x1B[38;2;0;0;255m ╚════╝ \x1B[39m \x1B[38;2;0;0;255m╚═╝\x1B[39m \x1B[38;2;0;0;255m  ╚═╝   \x1B[39m \x1B[38;2;0;0;255m╚═╝\x1B[39m                \x1B[38;2;0;0;255m╚══════╝\x1B[39m         \x1B[38;2;0;0;255m ╚╝╚═══╝ \x1B[39m \n\n  \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m ██\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m \x1B[38;2;255;0;0m▄▄███▄▄\x1B[39m\x1B[38;2;0;0;255m·\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m ██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m╗   \x1B[39m  \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗ \x1B[39m \x1B[38;2;255;0;0m    ██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m             \x1B[38;2;255;0;0m█\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m  \x1B[38;2;255;0;0m█\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m\x1B[38;2;255;0;0m█\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m  \n \x1B[38;2;255;0;0m████████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔════╝\x1B[39m \x1B[38;2;0;0;255m╚═╝\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m║   \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m   ██\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m         \x1B[38;2;0;0;255m╚╝\x1B[39m  \x1B[38;2;0;0;255m╚╝╚╝\x1B[39m  \n \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔═\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m  ██\x1B[39m\x1B[38;2;0;0;255m╔╝ \x1B[39m \x1B[38;2;255;0;0m████████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║   \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m  ██\x1B[39m\x1B[38;2;0;0;255m╔╝ \x1B[39m \x1B[38;2;0;0;255m╚═╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m               \n \x1B[38;2;255;0;0m████████\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;0;0;255m╚════\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m  \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔╝  \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔═\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔═╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║   \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m  \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔╝  \x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;0;0;255m╚═╝\x1B[39m               \n \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔═\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m███████\x1B[39m\x1B[38;2;0;0;255m║\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██████\x1B[39m\x1B[38;2;0;0;255m║  \x1B[39m \x1B[38;2;0;0;255m╚\x1B[39m\x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔╝\x1B[39m \x1B[38;2;255;0;0m██\x1B[39m\x1B[38;2;0;0;255m╔╝   \x1B[39m \x1B[38;2;0;0;255m╚═╝\x1B[39m \x1B[38;2;255;0;0m▄█\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m \x1B[38;2;255;0;0m▄█\x1B[39m\x1B[38;2;0;0;255m╗\x1B[39m           \n \x1B[38;2;0;0;255m ╚═╝ ╚═╝ \x1B[39m \x1B[38;2;0;0;255m╚═\x1B[39m\x1B[38;2;255;0;0m▀▀▀\x1B[39m\x1B[38;2;0;0;255m══╝\x1B[39m \x1B[38;2;0;0;255m╚═╝ ╚═╝\x1B[39m \x1B[38;2;0;0;255m╚═════╝  \x1B[39m \x1B[38;2;0;0;255m ╚═╝\x1B[39m \x1B[38;2;0;0;255m╚═╝ \x1B[39m \x1B[38;2;0;0;255m╚═╝    \x1B[39m     \x1B[38;2;255;0;0m▀\x1B[39m\x1B[38;2;0;0;255m═╝\x1B[39m \x1B[38;2;255;0;0m▀\x1B[39m\x1B[38;2;0;0;255m═╝\x1B[39m           \n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font chrome`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'chrome' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		' ╔═╗ ╔╗  ╔═╗ ╔╦╗ ╔═╗ ╔═╗ ╔═╗ ╦ ╦ ╦  ╦ ╦╔═ ╦   ╔╦╗ ╔╗╔ ╔═╗ ╔═╗ ╔═╗  ╦═╗ ╔═╗ ╔╦╗ \n' +
		' ╠═╣ ╠╩╗ ║    ║║ ║╣  ╠╣  ║ ╦ ╠═╣ ║  ║ ╠╩╗ ║   ║║║ ║║║ ║ ║ ╠═╝ ║═╬╗ ╠╦╝ ╚═╗  ║  \n' +
		' ╩ ╩ ╚═╝ ╚═╝ ═╩╝ ╚═╝ ╚   ╚═╝ ╩ ╩ ╩ ╚╝ ╩ ╩ ╩═╝ ╩ ╩ ╝╚╝ ╚═╝ ╩   ╚═╝╚ ╩╚═ ╚═╝  ╩  \n' +
		'\n' +
		' ╦ ╦ ╦  ╦ ╦ ╦  ╦ ╦ ╦ ╦ ╔═╗ ╔═╗ ╗  ═╗ ╔═╗ ╦   ╔═  ╔═╗ ╔═╗ ╔═╗ ╔═╗ ╦ ╔═╗          \n' +
		' ║ ║ ╚╗╔╝ ║║║ ╔╩╦╝ ╚╦╝ ╔═╝ ║═║ ║ ╔═╝  ╠║ ╚╬╝ ╚═╗ ╠═╗  ═╣ ╠═╣ ╚═╣ ║  ╔╝   ═╬═ ── \n' +
		' ╚═╝  ╚╝  ╚╩╝ ╩ ╩   ╩  ╚═╝ ╚═╝ ║ ╚══ ╚═╝  ╩  ══╝ ╚═╝   ╩ ╚═╝ ╚═╝ o  o  o        \n' +
		'\n' +
		'       ╔═╗    ╔╬╗ o╔  ╦  ╔ ╗  ╔       ╗ ╗╗ \n' +
		'    ══ ║╚╝ ╬╬ ╚╬╗ ╔╝ ╔╬═ ║ ║ ╔╝ o o        \n' +
		' ──    ╚══ ╬╬ ╚╬╝ ╝o ╚╝  ╚ ╝ ╝  o ╔ ╔      \n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font chrome in all colors`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'chrome', '-c', 'red,blue,green' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		' \u001b[38;2;255;0;0m╔═╗\u001b[39m \u001b[38;2;255;0;0m╔╗ \u001b[39m \u001b[38;2;255;0;0m╔═╗\u001b[39m \u001b[38;2;255;0;0m╔╦╗\u001b[39m \u001b[38;2;255;0;0m╔═╗\u001b[39m \u001b[38;2;255;0;0m╔═╗\u001b[39m \u001b[38;2;255;0;0m╔═╗\u001b[39m \u001b[38;2;255;0;0m╦ ╦\u001b[39m \u001b[38;2;255;0;0m╦\u001b[39m \u001b[38;2;255;0;0m ╦\u001b[39m \u001b[38;2;255;0;0m╦╔═\u001b[39m \u001b[38;2;255;0;0m╦  \u001b[39m \u001b[38;2;255;0;0m╔╦╗\u001b[39m \u001b[38;2;255;0;0m╔╗╔\u001b[39m \u001b[38;2;255;0;0m╔═╗\u001b[39m \u001b[38;2;255;0;0m╔═╗\u001b[39m \u001b[38;2;255;0;0m╔═╗ \u001b[39m \u001b[38;2;255;0;0m╦═╗\u001b[39m \u001b[38;2;255;0;0m╔═╗\u001b[39m \u001b[38;2;255;0;0m╔╦╗\u001b[39m \n \u001b[38;2;0;0;255m╠═╣\u001b[39m \u001b[38;2;0;0;255m╠╩╗\u001b[39m \u001b[38;2;0;0;255m║  \u001b[39m \u001b[38;2;0;0;255m ║║\u001b[39m \u001b[38;2;0;0;255m║╣ \u001b[39m \u001b[38;2;0;0;255m╠╣ \u001b[39m \u001b[38;2;0;0;255m║ ╦\u001b[39m \u001b[38;2;0;0;255m╠═╣\u001b[39m \u001b[38;2;0;0;255m║\u001b[39m \u001b[38;2;0;0;255m ║\u001b[39m \u001b[38;2;0;0;255m╠╩╗\u001b[39m \u001b[38;2;0;0;255m║  \u001b[39m \u001b[38;2;0;0;255m║║║\u001b[39m \u001b[38;2;0;0;255m║║║\u001b[39m \u001b[38;2;0;0;255m║ ║\u001b[39m \u001b[38;2;0;0;255m╠═╝\u001b[39m \u001b[38;2;0;0;255m║═╬╗\u001b[39m \u001b[38;2;0;0;255m╠╦╝\u001b[39m \u001b[38;2;0;0;255m╚═╗\u001b[39m \u001b[38;2;0;0;255m ║ \u001b[39m \n \u001b[38;2;0;128;0m╩ ╩\u001b[39m \u001b[38;2;0;128;0m╚═╝\u001b[39m \u001b[38;2;0;128;0m╚═╝\u001b[39m \u001b[38;2;0;128;0m═╩╝\u001b[39m \u001b[38;2;0;128;0m╚═╝\u001b[39m \u001b[38;2;0;128;0m╚  \u001b[39m \u001b[38;2;0;128;0m╚═╝\u001b[39m \u001b[38;2;0;128;0m╩ ╩\u001b[39m \u001b[38;2;0;128;0m╩\u001b[39m \u001b[38;2;0;128;0m╚╝\u001b[39m \u001b[38;2;0;128;0m╩ ╩\u001b[39m \u001b[38;2;0;128;0m╩═╝\u001b[39m \u001b[38;2;0;128;0m╩ ╩\u001b[39m \u001b[38;2;0;128;0m╝╚╝\u001b[39m \u001b[38;2;0;128;0m╚═╝\u001b[39m \u001b[38;2;0;128;0m╩  \u001b[39m \u001b[38;2;0;128;0m╚═╝╚\u001b[39m \u001b[38;2;0;128;0m╩╚═\u001b[39m \u001b[38;2;0;128;0m╚═╝\u001b[39m \u001b[38;2;0;128;0m ╩ \u001b[39m \n\n \u001b[38;2;255;0;0m╦ ╦\u001b[39m \u001b[38;2;255;0;0m╦  ╦\u001b[39m \u001b[38;2;255;0;0m╦ ╦\u001b[39m \u001b[38;2;255;0;0m ╦ ╦\u001b[39m \u001b[38;2;255;0;0m╦ ╦\u001b[39m \u001b[38;2;255;0;0m╔═╗\u001b[39m \u001b[38;2;255;0;0m╔═╗\u001b[39m \u001b[38;2;255;0;0m╗\u001b[39m \u001b[38;2;255;0;0m ═╗\u001b[39m \u001b[38;2;255;0;0m╔═╗\u001b[39m \u001b[38;2;255;0;0m╦  \u001b[39m \u001b[38;2;255;0;0m╔═ \u001b[39m \u001b[38;2;255;0;0m╔═╗\u001b[39m \u001b[38;2;255;0;0m╔═╗\u001b[39m \u001b[38;2;255;0;0m╔═╗\u001b[39m \u001b[38;2;255;0;0m╔═╗\u001b[39m \u001b[38;2;255;0;0m╦\u001b[39m \u001b[38;2;255;0;0m╔═╗\u001b[39m \u001b[38;2;255;0;0m \u001b[39m \u001b[38;2;255;0;0m   \u001b[39m \u001b[38;2;255;0;0m  \u001b[39m \n \u001b[38;2;0;0;255m║ ║\u001b[39m \u001b[38;2;0;0;255m╚╗╔╝\u001b[39m \u001b[38;2;0;0;255m║║║\u001b[39m \u001b[38;2;0;0;255m╔╩╦╝\u001b[39m \u001b[38;2;0;0;255m╚╦╝\u001b[39m \u001b[38;2;0;0;255m╔═╝\u001b[39m \u001b[38;2;0;0;255m║═║\u001b[39m \u001b[38;2;0;0;255m║\u001b[39m \u001b[38;2;0;0;255m╔═╝\u001b[39m \u001b[38;2;0;0;255m ╠║\u001b[39m \u001b[38;2;0;0;255m╚╬╝\u001b[39m \u001b[38;2;0;0;255m╚═╗\u001b[39m \u001b[38;2;0;0;255m╠═╗\u001b[39m \u001b[38;2;0;0;255m ═╣\u001b[39m \u001b[38;2;0;0;255m╠═╣\u001b[39m \u001b[38;2;0;0;255m╚═╣\u001b[39m \u001b[38;2;0;0;255m║\u001b[39m \u001b[38;2;0;0;255m ╔╝\u001b[39m \u001b[38;2;0;0;255m \u001b[39m \u001b[38;2;0;0;255m═╬═\u001b[39m \u001b[38;2;0;0;255m──\u001b[39m \n \u001b[38;2;0;128;0m╚═╝\u001b[39m \u001b[38;2;0;128;0m ╚╝ \u001b[39m \u001b[38;2;0;128;0m╚╩╝\u001b[39m \u001b[38;2;0;128;0m╩ ╩ \u001b[39m \u001b[38;2;0;128;0m ╩ \u001b[39m \u001b[38;2;0;128;0m╚═╝\u001b[39m \u001b[38;2;0;128;0m╚═╝\u001b[39m \u001b[38;2;0;128;0m║\u001b[39m \u001b[38;2;0;128;0m╚══\u001b[39m \u001b[38;2;0;128;0m╚═╝\u001b[39m \u001b[38;2;0;128;0m ╩ \u001b[39m \u001b[38;2;0;128;0m══╝\u001b[39m \u001b[38;2;0;128;0m╚═╝\u001b[39m \u001b[38;2;0;128;0m  ╩\u001b[39m \u001b[38;2;0;128;0m╚═╝\u001b[39m \u001b[38;2;0;128;0m╚═╝\u001b[39m \u001b[38;2;0;128;0mo\u001b[39m \u001b[38;2;0;128;0m o \u001b[39m \u001b[38;2;0;128;0mo\u001b[39m \u001b[38;2;0;128;0m   \u001b[39m \u001b[38;2;0;128;0m  \u001b[39m \n\n \u001b[38;2;255;0;0m  \u001b[39m \u001b[38;2;255;0;0m  \u001b[39m \u001b[38;2;255;0;0m╔═╗\u001b[39m \u001b[38;2;255;0;0m  \u001b[39m \u001b[38;2;255;0;0m╔╬╗\u001b[39m \u001b[38;2;255;0;0mo╔\u001b[39m \u001b[38;2;255;0;0m ╦ \u001b[39m \u001b[38;2;255;0;0m╔\u001b[39m \u001b[38;2;255;0;0m╗\u001b[39m \u001b[38;2;255;0;0m ╔\u001b[39m \u001b[38;2;255;0;0m \u001b[39m \u001b[38;2;255;0;0m \u001b[39m \u001b[38;2;255;0;0m \u001b[39m \u001b[38;2;255;0;0m╗\u001b[39m \u001b[38;2;255;0;0m╗╗\u001b[39m \n \u001b[38;2;0;0;255m  \u001b[39m \u001b[38;2;0;0;255m══\u001b[39m \u001b[38;2;0;0;255m║╚╝\u001b[39m \u001b[38;2;0;0;255m╬╬\u001b[39m \u001b[38;2;0;0;255m╚╬╗\u001b[39m \u001b[38;2;0;0;255m╔╝\u001b[39m \u001b[38;2;0;0;255m╔╬═\u001b[39m \u001b[38;2;0;0;255m║\u001b[39m \u001b[38;2;0;0;255m║\u001b[39m \u001b[38;2;0;0;255m╔╝\u001b[39m \u001b[38;2;0;0;255mo\u001b[39m \u001b[38;2;0;0;255mo\u001b[39m \u001b[38;2;255;0;0m \u001b[39m \u001b[38;2;255;0;0m \u001b[39m \u001b[38;2;255;0;0m  \u001b[39m \n \u001b[38;2;0;128;0m──\u001b[39m \u001b[38;2;0;128;0m  \u001b[39m \u001b[38;2;0;128;0m╚══\u001b[39m \u001b[38;2;0;128;0m╬╬\u001b[39m \u001b[38;2;0;128;0m╚╬╝\u001b[39m \u001b[38;2;0;128;0m╝o\u001b[39m \u001b[38;2;0;128;0m╚╝ \u001b[39m \u001b[38;2;0;128;0m╚\u001b[39m \u001b[38;2;0;128;0m╝\u001b[39m \u001b[38;2;0;128;0m╝ \u001b[39m \u001b[38;2;0;128;0mo\u001b[39m \u001b[38;2;0;128;0m╔\u001b[39m \u001b[38;2;0;128;0m╔\u001b[39m \u001b[38;2;0;128;0m \u001b[39m \u001b[38;2;0;128;0m  \u001b[39m \n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font 3d`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', '3d' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'_____/\\\\\\\\\\\\\\\\\\_____/\\\\\\\\\\\\\\\\\\\\\\\\\\__________/\\\\\\\\\\\\\\\\\\_\n' +
		' ___/\\\\\\\\\\\\\\\\\\\\\\\\\\__\\/\\\\\\/////////\\\\\\_____/\\\\\\////////__\n' +
		'  __/\\\\\\/////////\\\\\\_\\/\\\\\\_______\\/\\\\\\___/\\\\\\/___________\n' +
		'   _\\/\\\\\\_______\\/\\\\\\_\\/\\\\\\\\\\\\\\\\\\\\\\\\\\\\___/\\\\\\_____________\n' +
		'    _\\/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\_\\/\\\\\\/////////\\\\\\_\\/\\\\\\_____________\n' +
		'     _\\/\\\\\\/////////\\\\\\_\\/\\\\\\_______\\/\\\\\\_\\//\\\\\\____________\n' +
		'      _\\/\\\\\\_______\\/\\\\\\_\\/\\\\\\_______\\/\\\\\\__\\///\\\\\\__________\n' +
		'       _\\/\\\\\\_______\\/\\\\\\_\\/\\\\\\\\\\\\\\\\\\\\\\\\\\/_____\\////\\\\\\\\\\\\\\\\\\_\n' +
		'        _\\///________\\///__\\/////////////__________\\/////////__\n' +
		'\n' +
		'__/\\\\\\\\\\\\\\\\\\\\\\\\_____/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\__/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\_\n' +
		' _\\/\\\\\\////////\\\\\\__\\/\\\\\\///////////__\\/\\\\\\///////////__\n' +
		'  _\\/\\\\\\______\\//\\\\\\_\\/\\\\\\_____________\\/\\\\\\_____________\n' +
		'   _\\/\\\\\\_______\\/\\\\\\_\\/\\\\\\\\\\\\\\\\\\\\\\_____\\/\\\\\\\\\\\\\\\\\\\\\\_____\n' +
		'    _\\/\\\\\\_______\\/\\\\\\_\\/\\\\\\///////______\\/\\\\\\///////______\n' +
		'     _\\/\\\\\\_______\\/\\\\\\_\\/\\\\\\_____________\\/\\\\\\_____________\n' +
		'      _\\/\\\\\\_______/\\\\\\__\\/\\\\\\_____________\\/\\\\\\_____________\n' +
		'       _\\/\\\\\\\\\\\\\\\\\\\\\\\\/___\\/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\_\\/\\\\\\_____________\n' +
		'        _\\////////////_____\\///////////////__\\///______________\n' +
		'\n' +
		'_____/\\\\\\\\\\\\\\\\\\\\\\\\__/\\\\\\________/\\\\\\__/\\\\\\\\\\\\\\\\\\\\\\______/\\\\\\\\\\\\\\\\\\\\\\_\n' +
		' ___/\\\\\\//////////__\\/\\\\\\_______\\/\\\\\\_\\/////\\\\\\///______\\/////\\\\\\///__\n' +
		'  __/\\\\\\_____________\\/\\\\\\_______\\/\\\\\\_____\\/\\\\\\_____________\\/\\\\\\_____\n' +
		'   _\\/\\\\\\____/\\\\\\\\\\\\\\_\\/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\_____\\/\\\\\\_____________\\/\\\\\\_____\n' +
		'    _\\/\\\\\\___\\/////\\\\\\_\\/\\\\\\/////////\\\\\\_____\\/\\\\\\_____________\\/\\\\\\_____\n' +
		'     _\\/\\\\\\_______\\/\\\\\\_\\/\\\\\\_______\\/\\\\\\_____\\/\\\\\\_____________\\/\\\\\\_____\n' +
		'      _\\/\\\\\\_______\\/\\\\\\_\\/\\\\\\_______\\/\\\\\\_____\\/\\\\\\______/\\\\\\___\\/\\\\\\_____\n' +
		'       _\\//\\\\\\\\\\\\\\\\\\\\\\\\/__\\/\\\\\\_______\\/\\\\\\__/\\\\\\\\\\\\\\\\\\\\\\_\\//\\\\\\\\\\\\\\\\\\______\n' +
		'        __\\////////////____\\///________\\///__\\///////////___\\/////////_______\n' +
		'\n' +
		'__/\\\\\\________/\\\\\\__/\\\\\\______________/\\\\\\\\____________/\\\\\\\\_\n' +
		' _\\/\\\\\\_____/\\\\\\//__\\/\\\\\\_____________\\/\\\\\\\\\\\\________/\\\\\\\\\\\\_\n' +
		'  _\\/\\\\\\__/\\\\\\//_____\\/\\\\\\_____________\\/\\\\\\//\\\\\\____/\\\\\\//\\\\\\_\n' +
		'   _\\/\\\\\\\\\\\\//\\\\\\_____\\/\\\\\\_____________\\/\\\\\\\\///\\\\\\/\\\\\\/_\\/\\\\\\_\n' +
		'    _\\/\\\\\\//_\\//\\\\\\____\\/\\\\\\_____________\\/\\\\\\__\\///\\\\\\/___\\/\\\\\\_\n' +
		'     _\\/\\\\\\____\\//\\\\\\___\\/\\\\\\_____________\\/\\\\\\____\\///_____\\/\\\\\\_\n' +
		'      _\\/\\\\\\_____\\//\\\\\\__\\/\\\\\\_____________\\/\\\\\\_____________\\/\\\\\\_\n' +
		'       _\\/\\\\\\______\\//\\\\\\_\\/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\_\\/\\\\\\_____________\\/\\\\\\_\n' +
		'        _\\///________\\///__\\///////////////__\\///______________\\///__\n' +
		'\n' +
		'__/\\\\\\\\\\_____/\\\\\\_______/\\\\\\\\\\_______/\\\\\\\\\\\\\\\\\\\\\\\\\\__________/\\\\\\_______\n' +
		' _\\/\\\\\\\\\\\\___\\/\\\\\\_____/\\\\\\///\\\\\\____\\/\\\\\\/////////\\\\\\_____/\\\\\\\\/\\\\\\\\____\n' +
		'  _\\/\\\\\\/\\\\\\__\\/\\\\\\___/\\\\\\/__\\///\\\\\\__\\/\\\\\\_______\\/\\\\\\___/\\\\\\//\\////\\\\\\__\n' +
		'   _\\/\\\\\\//\\\\\\_\\/\\\\\\__/\\\\\\______\\//\\\\\\_\\/\\\\\\\\\\\\\\\\\\\\\\\\\\/___/\\\\\\______\\//\\\\\\_\n' +
		'    _\\/\\\\\\\\//\\\\\\\\/\\\\\\_\\/\\\\\\_______\\/\\\\\\_\\/\\\\\\/////////____\\//\\\\\\______/\\\\\\__\n' +
		'     _\\/\\\\\\_\\//\\\\\\/\\\\\\_\\//\\\\\\______/\\\\\\__\\/\\\\\\______________\\///\\\\\\\\/\\\\\\\\/___\n' +
		'      _\\/\\\\\\__\\//\\\\\\\\\\\\__\\///\\\\\\__/\\\\\\____\\/\\\\\\________________\\////\\\\\\//_____\n' +
		'       _\\/\\\\\\___\\//\\\\\\\\\\____\\///\\\\\\\\\\/_____\\/\\\\\\___________________\\///\\\\\\\\\\\\__\n' +
		'        _\\///_____\\/////_______\\/////_______\\///______________________\\//////___\n' +
		'\n' +
		'____/\\\\\\\\\\\\\\\\\\_________/\\\\\\\\\\\\\\\\\\\\\\____/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\_\n' +
		' __/\\\\\\///////\\\\\\_____/\\\\\\/////////\\\\\\_\\///////\\\\\\/////__\n' +
		'  _\\/\\\\\\_____\\/\\\\\\____\\//\\\\\\______\\///________\\/\\\\\\_______\n' +
		'   _\\/\\\\\\\\\\\\\\\\\\\\\\/______\\////\\\\\\_______________\\/\\\\\\_______\n' +
		'    _\\/\\\\\\//////\\\\\\_________\\////\\\\\\____________\\/\\\\\\_______\n' +
		'     _\\/\\\\\\____\\//\\\\\\___________\\////\\\\\\_________\\/\\\\\\_______\n' +
		'      _\\/\\\\\\_____\\//\\\\\\___/\\\\\\______\\//\\\\\\________\\/\\\\\\_______\n' +
		'       _\\/\\\\\\______\\//\\\\\\_\\///\\\\\\\\\\\\\\\\\\\\\\/_________\\/\\\\\\_______\n' +
		'        _\\///________\\///____\\///////////___________\\///________\n' +
		'\n' +
		'__/\\\\\\________/\\\\\\__/\\\\\\________/\\\\\\__/\\\\\\______________/\\\\\\_\n' +
		' _\\/\\\\\\_______\\/\\\\\\_\\/\\\\\\_______\\/\\\\\\_\\/\\\\\\_____________\\/\\\\\\_\n' +
		'  _\\/\\\\\\_______\\/\\\\\\_\\//\\\\\\______/\\\\\\__\\/\\\\\\_____________\\/\\\\\\_\n' +
		'   _\\/\\\\\\_______\\/\\\\\\__\\//\\\\\\____/\\\\\\___\\//\\\\\\____/\\\\\\____/\\\\\\__\n' +
		'    _\\/\\\\\\_______\\/\\\\\\___\\//\\\\\\__/\\\\\\_____\\//\\\\\\__/\\\\\\\\\\__/\\\\\\___\n' +
		'     _\\/\\\\\\_______\\/\\\\\\____\\//\\\\\\/\\\\\\_______\\//\\\\\\/\\\\\\/\\\\\\/\\\\\\____\n' +
		'      _\\//\\\\\\______/\\\\\\______\\//\\\\\\\\\\_________\\//\\\\\\\\\\\\//\\\\\\\\\\_____\n' +
		'       __\\///\\\\\\\\\\\\\\\\\\/________\\//\\\\\\___________\\//\\\\\\__\\//\\\\\\______\n' +
		'        ____\\/////////___________\\///_____________\\///____\\///_______\n' +
		'\n' +
		'__/\\\\\\_______/\\\\\\__/\\\\\\________/\\\\\\__/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\_____/\\\\\\\\\\\\\\____\n' +
		' _\\///\\\\\\___/\\\\\\/__\\///\\\\\\____/\\\\\\/__\\////////////\\\\\\____/\\\\\\/////\\\\\\__\n' +
		'  ___\\///\\\\\\\\\\\\/______\\///\\\\\\/\\\\\\/______________/\\\\\\/____/\\\\\\____\\//\\\\\\_\n' +
		'   _____\\//\\\\\\\\__________\\///\\\\\\/______________/\\\\\\/_____\\/\\\\\\_____\\/\\\\\\_\n' +
		'    ______\\/\\\\\\\\____________\\/\\\\\\_____________/\\\\\\/_______\\/\\\\\\_____\\/\\\\\\_\n' +
		'     ______/\\\\\\\\\\\\___________\\/\\\\\\___________/\\\\\\/_________\\/\\\\\\_____\\/\\\\\\_\n' +
		'      ____/\\\\\\////\\\\\\_________\\/\\\\\\_________/\\\\\\/___________\\//\\\\\\____/\\\\\\__\n' +
		'       __/\\\\\\/___\\///\\\\\\_______\\/\\\\\\________/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\__\\///\\\\\\\\\\\\\\/___\n' +
		'        _\\///_______\\///________\\///________\\///////////////_____\\///////_____\n' +
		'\n' +
		'______/\\\\\\____/\\\\\\\\\\\\\\\\\\_________/\\\\\\\\\\\\\\\\\\\\_____________/\\\\\\____\n' +
		' __/\\\\\\\\\\\\\\__/\\\\\\///////\\\\\\_____/\\\\\\///////\\\\\\__________/\\\\\\\\\\____\n' +
		'  _\\/////\\\\\\_\\///______\\//\\\\\\___\\///______/\\\\\\_________/\\\\\\/\\\\\\____\n' +
		'   _____\\/\\\\\\___________/\\\\\\/___________/\\\\\\//________/\\\\\\/\\/\\\\\\____\n' +
		'    _____\\/\\\\\\________/\\\\\\//____________\\////\\\\\\_____/\\\\\\/__\\/\\\\\\____\n' +
		'     _____\\/\\\\\\_____/\\\\\\//__________________\\//\\\\\\__/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\_\n' +
		'      _____\\/\\\\\\___/\\\\\\/____________/\\\\\\______/\\\\\\__\\///////////\\\\\\//__\n' +
		'       _____\\/\\\\\\__/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\_\\///\\\\\\\\\\\\\\\\\\/_____________\\/\\\\\\____\n' +
		'        _____\\/// _\\///////////////____\\/////////_______________\\///_____\n' +
		'\n' +
		'___/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\ ____________/\\\\\\\\\\__/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\_\n' +
		' __\\/\\\\\\///////////_ ________/\\\\\\\\////__\\/////////////\\\\\\_\n' +
		'  __\\/\\\\\\____________ _____/\\\\\\///__________________/\\\\\\/__\n' +
		'   __\\/\\\\\\\\\\\\\\\\\\\\\\\\_______/\\\\\\\\\\\\\\\\\\\\\\_____________/\\\\\\/____\n' +
		'    __\\////////////\\\\\\____/\\\\\\\\///////\\\\\\_________/\\\\\\/______\n' +
		'     _____________\\//\\\\\\__\\/\\\\\\______\\//\\\\\\______/\\\\\\/________\n' +
		'      __/\\\\\\________\\/\\\\\\__\\//\\\\\\______/\\\\\\_____/\\\\\\/__________\n' +
		'       _\\//\\\\\\\\\\\\\\\\\\\\\\\\\\/____\\///\\\\\\\\\\\\\\\\\\/____/\\\\\\/____________\n' +
		'        __\\/////////////________\\/////////_____\\///______________\n' +
		'\n' +
		'_____/\\\\\\\\\\\\\\\\\\_________/\\\\\\\\\\\\\\\\\\________/\\\\\\_______/\\\\\\\\\\\\\\___ _______\n' +
		' ___/\\\\\\///////\\\\\\_____/\\\\\\///////\\\\\\____/\\\\\\\\\\\\\\__/\\\\\\//////\\\\\\_ _______\n' +
		'  __\\/\\\\\\_____\\/\\\\\\____/\\\\\\______\\//\\\\\\__/\\\\\\\\\\\\\\\\\\_\\///_____\\//\\\\\\_______\n' +
		'   __\\///\\\\\\\\\\\\\\\\\\/____\\//\\\\\\_____/\\\\\\\\\\_\\//\\\\\\\\\\\\\\___________/\\\\\\_ _______\n' +
		'    ___/\\\\\\///////\\\\\\____\\///\\\\\\\\\\\\\\\\/\\\\\\__\\//\\\\\\\\\\_________/\\\\\\\\/__ _______\n' +
		'     __/\\\\\\______\\//\\\\\\_____\\////////\\/\\\\\\___\\//\\\\\\_________/\\\\\\/____ _______\n' +
		'      _\\//\\\\\\______/\\\\\\____/\\\\________/\\\\\\_____\\///_________\\///______ _______\n' +
		'       __\\///\\\\\\\\\\\\\\\\\\/____\\//\\\\\\\\\\\\\\\\\\\\\\/_______/\\\\\\_________/\\\\\\_____ __/\\\\\\_\n' +
		'        ____\\/////////_______\\///////////________\\///_________\\///______ _\\///__\n' +
		'\n' +
		'____________________________________________________________\n' +
		' ____________________________________________________________\n' +
		'  ______/\\\\\\__________________________________________________\n' +
		'   _____\\/\\\\\\______/\\\\\\\\\\\\\\\\\\\\\\____________________/\\\\\\\\\\\\\\\\\\\\_\n' +
		'    __/\\\\\\\\\\\\\\\\\\\\\\_\\///////////____________________\\//////////__\n' +
		'     _\\/////\\\\\\///___________________________________/\\\\\\\\\\\\\\\\\\\\_\n' +
		'      _____\\/\\\\\\_____________________________________\\//////////__\n' +
		'       _____\\///_____________________/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\______________\n' +
		'        _____________________________\\///////////////_______________\n' +
		'\n' +
		'____/\\\\\\\\\\\\\\\\\\\\_______/\\\\\\__/\\\\\\__________/\\\\\\_______\n' +
		' __/\\\\\\////////\\\\\\____\\/\\\\\\_\\/\\\\\\______/\\\\\\\\\\\\\\\\\\\\\\___\n' +
		'  _\\/\\\\\\__/\\\\\\\\\\\\\\\\\\__/\\\\\\\\\\\\\\\\\\\\\\\\\\__/\\\\\\///\\\\\\////\\\\_\n' +
		'   _\\/\\\\\\_\\/\\\\\\///\\\\\\_\\///\\\\\\///\\\\\\/__\\////\\\\\\\\\\\\__\\//__\n' +
		'    _\\/\\\\\\_\\/\\\\\\\\\\\\\\\\____\\/\\\\\\_\\/\\\\\\______\\////\\\\\\\\\\\\____\n' +
		'     _\\/\\\\\\_\\////////____/\\\\\\\\\\\\\\\\\\\\\\\\\\__/\\\\__\\/\\\\\\///\\\\\\_\n' +
		'      _\\//\\\\\\____________\\///\\\\\\///\\\\\\/__\\///\\\\\\\\\\\\\\\\\\\\\\/__\n' +
		'       __\\///\\\\\\\\\\\\\\\\\\\\\\\\___\\/\\\\\\_\\/\\\\\\_____\\/////\\\\\\///__ _\n' +
		'        ____\\////////////____\\///__\\///__________\\///________\n' +
		'\n' +
		'____/\\\\\\________/\\\\\\___________/\\\\\\____________/\\\\\\__/\\\\\\_____\n' +
		' ___/\\\\/\\\\_____/\\\\\\/_________/\\\\\\//\\\\\\________/\\\\\\/__\\///\\\\\\___\n' +
		'  __\\//\\\\\\____/\\\\\\/__________/\\\\\\_/\\\\\\________/\\\\\\______\\//\\\\\\__\n' +
		'   ___\\///___/\\\\\\/___________\\//\\\\\\\\//________/\\\\\\________\\//\\\\\\_\n' +
		'    ________/\\\\\\/____________/\\\\\\///\\\\\\_______\\/\\\\\\_________\\/\\\\\\_\n' +
		'     ______/\\\\\\/___/\\\\\\_____/\\\\\\/__\\///\\\\\\/\\\\\\_\\//\\\\\\________/\\\\\\__\n' +
		'      ____/\\\\\\/____/\\\\/\\\\___/\\\\\\______\\//\\\\\\//___\\//\\\\\\______/\\\\\\___\n' +
		'       __/\\\\\\/_____\\//\\\\\\___\\//\\\\\\\\\\\\\\\\\\\\\\//\\\\\\____\\///\\\\\\__/\\\\\\/____\n' +
		'        _\\///________\\///__ __\\///////////_\\///_______\\///__\\///______\n' +
		'\n' +
		'________________/\\\\\\______________________/\\\\\\___/\\\\\\/\\\\\\_\n' +
		' ______________/\\\\\\/______________________\\/\\\\\\__\\/\\\\\\/\\\\\\_\n' +
		'  ____________/\\\\\\/________________________\\///___\\///\\///__\n' +
		'   __________/\\\\\\/_____________/\\\\\\__________________________\n' +
		'    ________/\\\\\\/_________/\\\\\\_\\///___________________________\n' +
		'     ______/\\\\\\/__________\\///___/\\\\\\\\__/\\\\\\\\__________________\n' +
		'      ____/\\\\\\/__________________\\///\\\\_\\///\\\\__________________\n' +
		'       __/\\\\\\/_______________/\\\\\\__/\\\\/___/\\\\/___________________\n' +
		'        _\\///________________\\///__\\//____\\//_____________________\n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font 3d in all colors`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', '3d', '-c', 'red,blue' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\/////////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\////////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n  \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/////////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n   \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n    \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\/////////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n     \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\/////////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m___________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n      \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\u001b[39m\u001b[38;2;0;0;255m_________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n       \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\\\\\\\\\\\\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\////\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n        \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/////////////\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\/////////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n\n\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\////////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\///////////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\///////////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n  \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n   \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n    \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\///////\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\///////\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n     \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n      \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n       \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\\\\\\\\\\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n        \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\////////////\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///////////////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n\n\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\//////////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/////\\\\\\///\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\/////\\\\\\///\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n  \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n   \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n    \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\/////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\/////////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n     \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n      \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n       \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\\\\\\\\\\\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n        \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\////////////\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///////////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/////////\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n\n\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\//\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n  \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\//\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n   \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\\\\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\///\\\\\\/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n    \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\//\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\/\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n     \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n      \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n       \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n        \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///////////////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m______________\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n\n\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\///\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\/////////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\/\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n  \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\//\\////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n   \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\\\\\\\\\\\\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n    \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\//\\\\\\\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\/////////\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n     \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\\/\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n      \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\////\\\\\\//\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n       \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n        \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m\\/////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m\\/////\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m\\//////\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n\n\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\///////\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/////////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///////\\\\\\/////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n  \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n   \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\\\\\\\\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\////\\\\\\\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n    \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\//////\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m\\////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n     \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m\\////\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n      \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n       \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\\\\\\\\\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n        \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\///////////\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n\n\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n  \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n   \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n    \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n     \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\/\\\\\\/\\\\\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n      \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\\\\\\//\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n       \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\\\\\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n        \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\/////////\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n\n\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\////////////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n  \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n   \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n    \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n     \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n      \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\////\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n       \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n        \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///////////////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\///////\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n\n\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\///////\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\///////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n  \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n   \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\//\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n    \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\//\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m\\////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n     \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\//\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__________\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n      \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///////////\\\\\\//\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n       \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\\\\\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__________\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n        \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\/// \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///////////////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\/////////\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__________\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n\n\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\///////////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/////////////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n  \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\///\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n   \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n    \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\////////////\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\///////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n     \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n      \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n       \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\\\\\\\\\\\\\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\\\\\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m___________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n        \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/////////////\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\/////////\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n\n\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\///////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\///////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\//////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n  \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n   \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\\\\\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n    \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\///////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\\\\\\\\\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n     \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\////////\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n      \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n       \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\\\\\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\\\\\\\\\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n        \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\/////////\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\///////////\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n\n\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_________________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_________________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n  \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_________________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n   \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_________________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n    \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///////////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_________________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//////////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n     \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/////\\\\\\///\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_________________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n      \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_________________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//////////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n       \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n        \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///////////////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n\n\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\////////\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n  \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\///\\\\\\////\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n   \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\///\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\///\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\////\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\//\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n    \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\////\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n     \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\////////\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\///\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n      \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m___________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\///\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\\\\\\\\\\\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n       \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\\\\\\\\\\\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\/////\\\\\\///\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m \u001b[38;2;0;0;255m_\u001b[39m\n        \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\////////////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n\n\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\/\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n  \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n   \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\\//\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n    \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\///\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n     \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n      \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m/\\\\/\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\//\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n       \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\\\\\\\\\\\\\\\\\\\\\\//\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n        \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m________\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///////////\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m____\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n\n\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_______________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\/\\\\\\/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n  \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\///\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n   \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_________\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n    \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m__\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n     \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n      \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m___________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_____\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n       \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\/\u001b[39m\u001b[38;2;0;0;255m_____________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\\\\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\/\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m/\\\\/\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n        \u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_______________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\///\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;255;0;0m\\//\u001b[39m\u001b[38;2;0;0;255m___\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m______\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\u001b[38;2;0;0;255m_________\u001b[39m\u001b[38;2;0;0;255m_\u001b[39m\n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font huge`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'huge' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'  ▄▄▄▄▄▄▄▄▄▄▄   ▄▄▄▄▄▄▄▄▄▄    ▄▄▄▄▄▄▄▄▄▄▄   ▄▄▄▄▄▄▄▄▄▄    ▄▄▄▄▄▄▄▄▄▄▄  \n' +
		' ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░▌  ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░▌  ▐░░░░░░░░░░░▌ \n' +
		' ▐░█▀▀▀▀▀▀▀█░▌ ▐░█▀▀▀▀▀▀▀█░▌ ▐░█▀▀▀▀▀▀▀▀▀  ▐░█▀▀▀▀▀▀▀█░▌ ▐░█▀▀▀▀▀▀▀▀▀  \n' +
		' ▐░▌       ▐░▌ ▐░▌       ▐░▌ ▐░▌           ▐░▌       ▐░▌ ▐░▌           \n' +
		' ▐░█▄▄▄▄▄▄▄█░▌ ▐░█▄▄▄▄▄▄▄█░▌ ▐░▌           ▐░▌       ▐░▌ ▐░█▄▄▄▄▄▄▄▄▄  \n' +
		' ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░▌  ▐░▌           ▐░▌       ▐░▌ ▐░░░░░░░░░░░▌ \n' +
		' ▐░█▀▀▀▀▀▀▀█░▌ ▐░█▀▀▀▀▀▀▀█░▌ ▐░▌           ▐░▌       ▐░▌ ▐░█▀▀▀▀▀▀▀▀▀  \n' +
		' ▐░▌       ▐░▌ ▐░▌       ▐░▌ ▐░▌           ▐░▌       ▐░▌ ▐░▌           \n' +
		' ▐░▌       ▐░▌ ▐░█▄▄▄▄▄▄▄█░▌ ▐░█▄▄▄▄▄▄▄▄▄  ▐░█▄▄▄▄▄▄▄█░▌ ▐░█▄▄▄▄▄▄▄▄▄  \n' +
		' ▐░▌       ▐░▌ ▐░░░░░░░░░░▌  ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░▌  ▐░░░░░░░░░░░▌ \n' +
		'  ▀         ▀   ▀▀▀▀▀▀▀▀▀▀    ▀▀▀▀▀▀▀▀▀▀▀   ▀▀▀▀▀▀▀▀▀▀    ▀▀▀▀▀▀▀▀▀▀▀  \n' +
		'\n' +
		'  ▄▄▄▄▄▄▄▄▄▄▄   ▄▄▄▄▄▄▄▄▄▄▄   ▄         ▄   ▄▄▄▄▄▄▄▄▄▄▄   ▄▄▄▄▄▄▄▄▄▄▄   ▄    ▄  \n' +
		' ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░░▌ ▐░▌       ▐░▌ ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░░▌ ▐░▌  ▐░▌ \n' +
		' ▐░█▀▀▀▀▀▀▀▀▀  ▐░█▀▀▀▀▀▀▀▀▀  ▐░▌       ▐░▌  ▀▀▀▀█░█▀▀▀▀   ▀▀▀▀▀█░█▀▀▀  ▐░▌ ▐░▌  \n' +
		' ▐░▌           ▐░▌           ▐░▌       ▐░▌      ▐░▌            ▐░▌     ▐░▌▐░▌   \n' +
		' ▐░█▄▄▄▄▄▄▄▄▄  ▐░▌ ▄▄▄▄▄▄▄▄  ▐░█▄▄▄▄▄▄▄█░▌      ▐░▌            ▐░▌     ▐░▌░▌    \n' +
		' ▐░░░░░░░░░░░▌ ▐░▌▐░░░░░░░░▌ ▐░░░░░░░░░░░▌      ▐░▌            ▐░▌     ▐░░▌     \n' +
		' ▐░█▀▀▀▀▀▀▀▀▀  ▐░▌ ▀▀▀▀▀▀█░▌ ▐░█▀▀▀▀▀▀▀█░▌      ▐░▌            ▐░▌     ▐░▌░▌    \n' +
		' ▐░▌           ▐░▌       ▐░▌ ▐░▌       ▐░▌      ▐░▌            ▐░▌     ▐░▌▐░▌   \n' +
		' ▐░▌           ▐░█▄▄▄▄▄▄▄█░▌ ▐░▌       ▐░▌  ▄▄▄▄█░█▄▄▄▄   ▄▄▄▄▄█░▌     ▐░▌ ▐░▌  \n' +
		' ▐░▌           ▐░░░░░░░░░░░▌ ▐░▌       ▐░▌ ▐░░░░░░░░░░░▌ ▐░░░░░░░▌     ▐░▌  ▐░▌ \n' +
		'  ▀             ▀▀▀▀▀▀▀▀▀▀▀   ▀         ▀   ▀▀▀▀▀▀▀▀▀▀▀   ▀▀▀▀▀▀▀       ▀    ▀  \n' +
		'\n' +
		'  ▄             ▄▄       ▄▄   ▄▄        ▄   ▄▄▄▄▄▄▄▄▄▄▄   ▄▄▄▄▄▄▄▄▄▄▄  \n' +
		' ▐░▌           ▐░░▌     ▐░░▌ ▐░░▌      ▐░▌ ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░░▌ \n' +
		' ▐░▌           ▐░▌░▌   ▐░▐░▌ ▐░▌░▌     ▐░▌ ▐░█▀▀▀▀▀▀▀█░▌ ▐░█▀▀▀▀▀▀▀█░▌ \n' +
		' ▐░▌           ▐░▌▐░▌ ▐░▌▐░▌ ▐░▌▐░▌    ▐░▌ ▐░▌       ▐░▌ ▐░▌       ▐░▌ \n' +
		' ▐░▌           ▐░▌ ▐░▐░▌ ▐░▌ ▐░▌ ▐░▌   ▐░▌ ▐░▌       ▐░▌ ▐░█▄▄▄▄▄▄▄█░▌ \n' +
		' ▐░▌           ▐░▌  ▐░▌  ▐░▌ ▐░▌  ▐░▌  ▐░▌ ▐░▌       ▐░▌ ▐░░░░░░░░░░░▌ \n' +
		' ▐░▌           ▐░▌   ▀   ▐░▌ ▐░▌   ▐░▌ ▐░▌ ▐░▌       ▐░▌ ▐░█▀▀▀▀▀▀▀▀▀  \n' +
		' ▐░▌           ▐░▌       ▐░▌ ▐░▌    ▐░▌▐░▌ ▐░▌       ▐░▌ ▐░▌           \n' +
		' ▐░█▄▄▄▄▄▄▄▄▄  ▐░▌       ▐░▌ ▐░▌     ▐░▐░▌ ▐░█▄▄▄▄▄▄▄█░▌ ▐░▌           \n' +
		' ▐░░░░░░░░░░░▌ ▐░▌       ▐░▌ ▐░▌      ▐░░▌ ▐░░░░░░░░░░░▌ ▐░▌           \n' +
		'  ▀▀▀▀▀▀▀▀▀▀▀   ▀         ▀   ▀        ▀▀   ▀▀▀▀▀▀▀▀▀▀▀   ▀            \n' +
		'\n' +
		'  ▄▄▄▄▄▄▄▄▄▄▄   ▄▄▄▄▄▄▄▄▄▄▄   ▄▄▄▄▄▄▄▄▄▄▄   ▄▄▄▄▄▄▄▄▄▄▄   ▄         ▄  \n' +
		' ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░░▌ ▐░▌       ▐░▌ \n' +
		' ▐░█▀▀▀▀▀▀▀█░▌ ▐░█▀▀▀▀▀▀▀█░▌ ▐░█▀▀▀▀▀▀▀▀▀   ▀▀▀▀█░█▀▀▀▀  ▐░▌       ▐░▌ \n' +
		' ▐░▌       ▐░▌ ▐░▌       ▐░▌ ▐░▌                ▐░▌      ▐░▌       ▐░▌ \n' +
		' ▐░▌       ▐░▌ ▐░█▄▄▄▄▄▄▄█░▌ ▐░█▄▄▄▄▄▄▄▄▄       ▐░▌      ▐░▌       ▐░▌ \n' +
		' ▐░▌       ▐░▌ ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░░▌      ▐░▌      ▐░▌       ▐░▌ \n' +
		' ▐░█▄▄▄▄▄▄▄█░▌ ▐░█▀▀▀▀█░█▀▀   ▀▀▀▀▀▀▀▀▀█░▌      ▐░▌      ▐░▌       ▐░▌ \n' +
		' ▐░░░░░░░░░░░▌ ▐░▌     ▐░▌             ▐░▌      ▐░▌      ▐░▌       ▐░▌ \n' +
		'  ▀▀▀▀▀▀█░█▀▀  ▐░▌      ▐░▌   ▄▄▄▄▄▄▄▄▄█░▌      ▐░▌      ▐░█▄▄▄▄▄▄▄█░▌ \n' +
		'         ▐░▌   ▐░▌       ▐░▌ ▐░░░░░░░░░░░▌      ▐░▌      ▐░░░░░░░░░░░▌ \n' +
		'          ▀     ▀         ▀   ▀▀▀▀▀▀▀▀▀▀▀        ▀        ▀▀▀▀▀▀▀▀▀▀▀  \n' +
		'\n' +
		'  ▄               ▄   ▄         ▄   ▄       ▄   ▄         ▄   ▄▄▄▄▄▄▄  \n' +
		' ▐░▌             ▐░▌ ▐░▌       ▐░▌ ▐░▌     ▐░▌ ▐░▌       ▐░▌ ▐░░░░░░░▌ \n' +
		'  ▐░▌           ▐░▌  ▐░▌       ▐░▌  ▐░▌   ▐░▌  ▐░▌       ▐░▌  ▀▀▀▀▀█░▌ \n' +
		'   ▐░▌         ▐░▌   ▐░▌       ▐░▌   ▐░▌ ▐░▌   ▐░▌       ▐░▌      ▐░▌  \n' +
		'    ▐░▌       ▐░▌    ▐░▌   ▄   ▐░▌    ▐░▐░▌    ▐░█▄▄▄▄▄▄▄█░▌     ▐░▌   \n' +
		'     ▐░▌     ▐░▌     ▐░▌  ▐░▌  ▐░▌     ▐░▌     ▐░░░░░░░░░░░▌    ▐░▌    \n' +
		'      ▐░▌   ▐░▌      ▐░▌ ▐░▌░▌ ▐░▌    ▐░▌░▌     ▀▀▀▀█░█▀▀▀▀    ▐░▌     \n' +
		'       ▐░▌ ▐░▌       ▐░▌▐░▌ ▐░▌▐░▌   ▐░▌ ▐░▌        ▐░▌       ▐░▌      \n' +
		'        ▐░▐░▌        ▐░▌░▌   ▐░▐░▌  ▐░▌   ▐░▌       ▐░▌      ▐░█▄▄▄▄▄  \n' +
		'         ▐░▌         ▐░░▌     ▐░░▌ ▐░▌     ▐░▌      ▐░▌      ▐░░░░░░░▌ \n' +
		'          ▀           ▀▀       ▀▀   ▀       ▀        ▀        ▀▀▀▀▀▀▀  \n' +
		'\n' +
		'   ▄▄▄▄▄▄▄▄▄       ▄▄▄▄       ▄▄▄▄▄▄▄▄▄▄▄   ▄▄▄▄▄▄▄▄▄▄▄   ▄         ▄  \n' +
		'  ▐░░░░░░░░░▌    ▄█░░░░▌     ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░░▌ ▐░▌       ▐░▌ \n' +
		' ▐░█░█▀▀▀▀▀█░▌  ▐░░▌▐░░▌      ▀▀▀▀▀▀▀▀▀█░▌  ▀▀▀▀▀▀▀▀▀█░▌ ▐░▌       ▐░▌ \n' +
		' ▐░▌▐░▌    ▐░▌   ▀▀ ▐░░▌               ▐░▌           ▐░▌ ▐░▌       ▐░▌ \n' +
		' ▐░▌ ▐░▌   ▐░▌      ▐░░▌               ▐░▌  ▄▄▄▄▄▄▄▄▄█░▌ ▐░█▄▄▄▄▄▄▄█░▌ \n' +
		' ▐░▌  ▐░▌  ▐░▌      ▐░░▌      ▄▄▄▄▄▄▄▄▄█░▌ ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░░▌ \n' +
		' ▐░▌   ▐░▌ ▐░▌      ▐░░▌     ▐░░░░░░░░░░░▌  ▀▀▀▀▀▀▀▀▀█░▌  ▀▀▀▀▀▀▀▀▀█░▌ \n' +
		' ▐░▌    ▐░▌▐░▌      ▐░░▌     ▐░█▀▀▀▀▀▀▀▀▀            ▐░▌           ▐░▌ \n' +
		' ▐░█▄▄▄▄▄█░█░▌  ▄▄▄▄█░░█▄▄▄  ▐░█▄▄▄▄▄▄▄▄▄   ▄▄▄▄▄▄▄▄▄█░▌           ▐░▌ \n' +
		'  ▐░░░░░░░░░▌  ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░░▌           ▐░▌ \n' +
		'   ▀▀▀▀▀▀▀▀▀    ▀▀▀▀▀▀▀▀▀▀▀   ▀▀▀▀▀▀▀▀▀▀▀   ▀▀▀▀▀▀▀▀▀▀▀             ▀  \n' +
		'\n' +
		'  ▄▄▄▄▄▄▄▄▄▄▄   ▄▄▄▄▄▄▄▄▄▄▄   ▄▄▄▄▄▄▄▄▄▄▄   ▄▄▄▄▄▄▄▄▄▄▄   ▄▄▄▄▄▄▄▄▄▄▄   ▄▄  \n' +
		' ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░░▌ ▐░░▌ \n' +
		' ▐░█▀▀▀▀▀▀▀▀▀  ▐░█▀▀▀▀▀▀▀▀▀   ▀▀▀▀▀▀▀▀▀█░▌ ▐░█▀▀▀▀▀▀▀█░▌ ▐░█▀▀▀▀▀▀▀█░▌ ▐░░▌ \n' +
		' ▐░█▄▄▄▄▄▄▄▄▄  ▐░▌                    ▐░▌  ▐░▌       ▐░▌ ▐░▌       ▐░▌ ▐░░▌ \n' +
		' ▐░░░░░░░░░░░▌ ▐░█▄▄▄▄▄▄▄▄▄          ▐░▌   ▐░█▄▄▄▄▄▄▄█░▌ ▐░█▄▄▄▄▄▄▄█░▌ ▐░░▌ \n' +
		'  ▀▀▀▀▀▀▀▀▀█░▌ ▐░░░░░░░░░░░▌        ▐░▌     ▐░░░░░░░░░▌  ▐░░░░░░░░░░░▌ ▐░░▌ \n' +
		'           ▐░▌ ▐░█▀▀▀▀▀▀▀█░▌       ▐░▌     ▐░█▀▀▀▀▀▀▀█░▌  ▀▀▀▀▀▀▀▀▀█░▌ ▐░░▌ \n' +
		'           ▐░▌ ▐░▌       ▐░▌      ▐░▌      ▐░▌       ▐░▌           ▐░▌  ▀▀  \n' +
		'  ▄▄▄▄▄▄▄▄▄█░▌ ▐░█▄▄▄▄▄▄▄█░▌     ▐░▌       ▐░█▄▄▄▄▄▄▄█░▌  ▄▄▄▄▄▄▄▄▄█░▌  ▄▄  \n' +
		' ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░░▌    ▐░▌        ▐░░░░░░░░░░░▌ ▐░░░░░░░░░░░▌ ▐░░▌ \n' +
		'  ▀▀▀▀▀▀▀▀▀▀▀   ▀▀▀▀▀▀▀▀▀▀▀      ▀          ▀▀▀▀▀▀▀▀▀▀▀   ▀▀▀▀▀▀▀▀▀▀▀   ▀▀  \n' +
		'\n' +
		'     ▄▄▄▄▄▄▄                                            ▄▄▄▄▄▄▄▄▄▄▄▄  \n' +
		'   ▄█░░░░░░█▄                                          ▐░░░░░░░░░░░░▌ \n' +
		'  ▐░░▌▀▀▀▀█░░▌          ▄▄                      ▄▄▄▄▄  ▐░█▀▀▀▀▀▀▀▀█░▌ \n' +
		'   ▀▀  ▄▄▄█░░▌         ▐░░▌                    ▐░░░░░▌ ▐░▌        ▐░▌ \n' +
		'     ▄█░░░░░█        ▄▄█░░█▄▄   ▄▄▄▄▄           ▀▀▀▀▀  ▐░▌  ▄▄▄▄  ▐░▌ \n' +
		'    ▐░░▌▀▀▀▀        ▐░░░░░░░░▌ ▐░░░░░▌                 ▐░▌ █░░░░█ ▐░▌ \n' +
		'    ▐░░▌             ▀▀█░░█▀▀   ▀▀▀▀▀           ▄▄▄▄▄  ▐░▌▐░████░▄█░▌ \n' +
		'     ▀▀                ▐░░▌             ▄▄▄▄▄  ▐░░░░░▌ ▐░▌ █░░░░░░░░▌ \n' +
		'     ▄▄         ▄▄      ▀▀             ▐░░░░░▌  ▀▀▀▀▀  ▐░▌▄▄███████░▌ \n' +
		'    ▐░░▌       ▐░░▌                     ▀▀▀▀▀          ▐░░░░░░░░░░░░▌ \n' +
		'     ▀▀         ▀▀                                      ▀▀▀▀▀▀▀▀▀▀▀▀  \n' +
		'\n' +
		'    ▄         ▄          ▄                ▄   ▄▄▄▄▄▄▄        ▄▄▄▄▄   ▄▄▄▄▄   \n' +
		'   ▐░▌       ▐░▌    ▄▄▄▄█░█▄▄▄▄    ▄     ▐░▌ ▐░░░░░░░▌      ▐░░░░░▌ ▐░░░░░▌  \n' +
		'  ▄█░█▄▄▄▄▄▄▄█░█▄  ▐░░░░░░░░░░░▌  ▐░▌   ▐░▌  ▐░█▀▀▀█░▌     ▐░░█▀▀▀   ▀▀▀█░░▌ \n' +
		' ▐░░░░░░░░░░░░░░░▌ ▐░█▀▀█░█▀▀▀▀    ▀   ▐░▌   ▐░▌   ▐░▌     ▐░░▌         ▐░░▌ \n' +
		'  ▀█░█▀▀▀▀▀▀▀█░█▀  ▐░█▄▄█░█▄▄▄▄       ▐░▌    ▐░█▄▄▄█░▌     ▐░░▌         ▐░░▌ \n' +
		'   ▐░▌       ▐░▌   ▐░░░░░░░░░░░▌     ▐░▌      ▐░░░░░░▌     ▐░░▌         ▐░░▌ \n' +
		'  ▄█░█▄▄▄▄▄▄▄█░█▄   ▀▀▀▀█░█▀▀█░▌    ▐░▌      ▐░█▀▀▀▀█░▌ ▄  ▐░░▌         ▐░░▌ \n' +
		' ▐░░░░░░░░░░░░░░░▌  ▄▄▄▄█░█▄▄█░▌   ▐░▌   ▄   ▐░▌     ▐░█░▌ ▐░░▌         ▐░░▌ \n' +
		'  ▀█░█▀▀▀▀▀▀▀█░█▀  ▐░░░░░░░░░░░▌  ▐░▌   ▐░▌  ▐░█▄▄▄▄█░▌    ▐░░█▄▄▄   ▄▄▄█░░▌ \n' +
		'   ▐░▌       ▐░▌    ▀▀▀▀█░█▀▀▀▀  ▐░▌     ▀   ▐░░░░░░▌▐░▌    ▐░░░░░▌ ▐░░░░░▌  \n' +
		'    ▀         ▀          ▀        ▀           ▀▀▀▀▀▀  ▀      ▀▀▀▀▀   ▀▀▀▀▀   \n' +
		'\n' +
		'          ▄                  ▄   ▄  ▄  \n' +
		'         ▐░▌                ▐░▐ ▐░▐▐░▐ \n' +
		'        ▐░▌   ▄▄   ▄▄       ▐░▐ ▐░▐▐░▐ \n' +
		'       ▐░▌   ▐░░▌ ▐░░▌       ▀   ▀  ▀  \n' +
		'      ▐░▌     ▀▀   ▀▀                  \n' +
		'     ▐░▌                               \n' +
		'    ▐░▌       ▄▄   ▄▄                  \n' +
		'   ▐░▌       ▐░░▌ ▐░░▌  ▄▄             \n' +
		'  ▐░▌         ▀▀   ▀▌  ▐░░▌            \n' +
		' ▐░▌               ▀    ▀▌             \n' +
		'  ▀                     ▀              \n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font huge in all colors`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'huge', '-c', 'red,blue' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'  \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄\u001b[39m    \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄\u001b[39m    \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m  \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀▀▀\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀▀▀\u001b[39m  \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄▄▄\u001b[39m  \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀▀▀\u001b[39m  \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄▄▄\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄▄▄\u001b[39m  \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n  \u001b[38;2;255;0;0m▀         ▀\u001b[39m   \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀\u001b[39m    \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀▀\u001b[39m   \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀\u001b[39m    \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀▀\u001b[39m  \n\n  \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄         ▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄    ▄\u001b[39m  \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌  ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀▀▀\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀▀▀\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀\u001b[39m   \u001b[38;2;255;0;0m▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m            \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m   \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄▄▄\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▄▄▄▄▄▄▄▄\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m            \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m    \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m            \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀▀▀\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m            \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m    \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m            \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m   \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌  ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n  \u001b[38;2;255;0;0m▀\u001b[39m             \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀▀\u001b[39m   \u001b[38;2;255;0;0m▀         ▀\u001b[39m   \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀▀\u001b[39m   \u001b[38;2;255;0;0m▀▀▀▀▀▀▀\u001b[39m       \u001b[38;2;255;0;0m▀    ▀\u001b[39m  \n\n  \u001b[38;2;255;0;0m▄\u001b[39m             \u001b[38;2;255;0;0m▄▄       ▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄        ▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m  \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌     ▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌      ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌   ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌     ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌    ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌   ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌  ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌  ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌  ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌  ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌   ▀   ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌   ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀▀▀\u001b[39m  \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌    ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄▄▄\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌     ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌      ▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \n  \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀▀\u001b[39m   \u001b[38;2;255;0;0m▀         ▀\u001b[39m   \u001b[38;2;255;0;0m▀        ▀▀\u001b[39m   \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀▀\u001b[39m   \u001b[38;2;255;0;0m▀\u001b[39m            \n\n  \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄         ▄\u001b[39m  \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀▀▀\u001b[39m   \u001b[38;2;255;0;0m▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m                \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄▄▄\u001b[39m       \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀\u001b[39m   \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌     ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m             \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n  \u001b[38;2;255;0;0m▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌      ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n         \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m   \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n          \u001b[38;2;255;0;0m▀\u001b[39m     \u001b[38;2;255;0;0m▀         ▀\u001b[39m   \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀▀\u001b[39m        \u001b[38;2;255;0;0m▀\u001b[39m        \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀▀\u001b[39m  \n\n  \u001b[38;2;255;0;0m▄               ▄\u001b[39m   \u001b[38;2;255;0;0m▄         ▄\u001b[39m   \u001b[38;2;255;0;0m▄       ▄\u001b[39m   \u001b[38;2;255;0;0m▄         ▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄\u001b[39m  \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌             ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌     ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌           ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌   ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n   \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌         ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m   \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m   \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m   \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \n    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌   ▄   ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m   \n     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌     ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌  ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌  ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m    \n      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌   ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀\u001b[39m    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \n       \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m       \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m   \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m        \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m       \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \n        \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m        \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌   ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌   ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m       \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄\u001b[39m  \n         \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m         \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌     ▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌     ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n          \u001b[38;2;255;0;0m▀\u001b[39m           \u001b[38;2;255;0;0m▀▀       ▀▀\u001b[39m   \u001b[38;2;255;0;0m▀       ▀\u001b[39m        \u001b[38;2;255;0;0m▀\u001b[39m        \u001b[38;2;255;0;0m▀▀▀▀▀▀▀\u001b[39m  \n\n   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄\u001b[39m       \u001b[38;2;255;0;0m▄▄▄▄\u001b[39m       \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄         ▄\u001b[39m  \n  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m    \u001b[38;2;255;0;0m▄█\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌    ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m   \u001b[38;2;255;0;0m▀▀ ▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m               \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌   ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m               \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌  ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌  ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌   ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌    ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀▀▀\u001b[39m            \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n   \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀\u001b[39m    \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀▀\u001b[39m   \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀▀\u001b[39m   \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀▀\u001b[39m             \u001b[38;2;255;0;0m▀\u001b[39m  \n\n  \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄\u001b[39m  \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀▀▀\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀▀▀\u001b[39m   \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄▄▄\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m                    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄▄▄\u001b[39m          \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m   \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n  \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m        \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m       \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m           \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▀▀\u001b[39m  \n  \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m       \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▄▄\u001b[39m  \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m        \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n  \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀▀\u001b[39m   \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀▀\u001b[39m      \u001b[38;2;255;0;0m▀\u001b[39m          \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀▀\u001b[39m   \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀▀\u001b[39m   \u001b[38;2;255;0;0m▀▀\u001b[39m  \n\n     \u001b[38;2;255;0;0m▄▄▄▄▄▄▄\u001b[39m                                            \u001b[38;2;255;0;0m▄▄▄▄▄▄▄▄▄▄▄▄\u001b[39m  \n   \u001b[38;2;255;0;0m▄█\u001b[39m\u001b[38;2;0;0;255m░░░░░░\u001b[39m\u001b[38;2;255;0;0m█▄\u001b[39m                                          \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m          \u001b[38;2;255;0;0m▄▄\u001b[39m                      \u001b[38;2;255;0;0m▄▄▄▄▄\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n   \u001b[38;2;255;0;0m▀▀  ▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m         \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m                    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌        ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n     \u001b[38;2;255;0;0m▄█\u001b[39m\u001b[38;2;0;0;255m░░░░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m        \u001b[38;2;255;0;0m▄▄█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄\u001b[39m           \u001b[38;2;255;0;0m▀▀▀▀▀\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌  ▄▄▄▄  ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌▀▀▀▀\u001b[39m        \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m                 \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ █\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;255;0;0m█ ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m             \u001b[38;2;255;0;0m▀▀█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█▀▀\u001b[39m   \u001b[38;2;255;0;0m▀▀▀▀▀\u001b[39m           \u001b[38;2;255;0;0m▄▄▄▄▄\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n     \u001b[38;2;255;0;0m▀▀\u001b[39m                \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m             \u001b[38;2;255;0;0m▄▄▄▄▄\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ █\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n     \u001b[38;2;255;0;0m▄▄\u001b[39m         \u001b[38;2;255;0;0m▄▄\u001b[39m      \u001b[38;2;255;0;0m▀▀\u001b[39m             \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▀▀▀▀▀\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌▄▄███████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m       \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m                     \u001b[38;2;255;0;0m▀▀▀▀▀\u001b[39m          \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n     \u001b[38;2;255;0;0m▀▀\u001b[39m         \u001b[38;2;255;0;0m▀▀\u001b[39m                                      \u001b[38;2;255;0;0m▀▀▀▀▀▀▀▀▀▀▀▀\u001b[39m  \n\n    \u001b[38;2;255;0;0m▄         ▄\u001b[39m          \u001b[38;2;255;0;0m▄\u001b[39m                \u001b[38;2;255;0;0m▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄▄▄\u001b[39m        \u001b[38;2;255;0;0m▄▄▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄▄▄\u001b[39m   \n   \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m    \u001b[38;2;255;0;0m▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄\u001b[39m    \u001b[38;2;255;0;0m▄     ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \n  \u001b[38;2;255;0;0m▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌   ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀\u001b[39m   \u001b[38;2;255;0;0m▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀\u001b[39m    \u001b[38;2;255;0;0m▀   ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m   \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌   ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m         \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n  \u001b[38;2;255;0;0m▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄\u001b[39m       \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m         \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n   \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m   \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m         \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n  \u001b[38;2;255;0;0m▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄\u001b[39m   \u001b[38;2;255;0;0m▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌ ▄\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m         \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m   \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌   ▄\u001b[39m   \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌     ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m         \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n  \u001b[38;2;255;0;0m▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌   ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█▄▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄▄█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \n   \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌       ▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m    \u001b[38;2;255;0;0m▀▀▀▀█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█▀▀▀▀\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌     ▀\u001b[39m   \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░░\u001b[39m\u001b[38;2;255;0;0m▌▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░░░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \n    \u001b[38;2;255;0;0m▀         ▀\u001b[39m          \u001b[38;2;255;0;0m▀\u001b[39m        \u001b[38;2;255;0;0m▀\u001b[39m           \u001b[38;2;255;0;0m▀▀▀▀▀▀  ▀\u001b[39m      \u001b[38;2;255;0;0m▀▀▀▀▀\u001b[39m   \u001b[38;2;255;0;0m▀▀▀▀▀\u001b[39m   \n\n          \u001b[38;2;255;0;0m▄\u001b[39m                  \u001b[38;2;255;0;0m▄\u001b[39m   \u001b[38;2;255;0;0m▄  ▄\u001b[39m  \n         \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m                \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▐\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▐▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▐\u001b[39m \n        \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m   \u001b[38;2;255;0;0m▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄\u001b[39m       \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▐\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▐▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▐\u001b[39m \n       \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m   \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m       \u001b[38;2;255;0;0m▀\u001b[39m   \u001b[38;2;255;0;0m▀  ▀\u001b[39m  \n      \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m     \u001b[38;2;255;0;0m▀▀\u001b[39m   \u001b[38;2;255;0;0m▀▀\u001b[39m                  \n     \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m                               \n    \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m       \u001b[38;2;255;0;0m▄▄\u001b[39m   \u001b[38;2;255;0;0m▄▄\u001b[39m                  \n   \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m       \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m  \u001b[38;2;255;0;0m▄▄\u001b[39m             \n  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m         \u001b[38;2;255;0;0m▀▀\u001b[39m   \u001b[38;2;255;0;0m▀▌\u001b[39m  \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m            \n \u001b[38;2;255;0;0m▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m               \u001b[38;2;255;0;0m▀\u001b[39m    \u001b[38;2;255;0;0m▀▌\u001b[39m             \n  \u001b[38;2;255;0;0m▀\u001b[39m                     \u001b[38;2;255;0;0m▀\u001b[39m              \n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font shade`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'shade' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░\n' +
		'░░██░░███░░████░███░░████░████░░███░█░░█░███░███░░█░░█░█░░░░█░░█░█░░█░░██░░███░░\n' +
		'░█  █░█  █░█   ░█  █░█   ░█   ░█   ░█░░█░ █ ░  █░░█░░█░█░░░░████░██░█░█  █░█  █░\n' +
		'░████░███ ░█░░░░█░░█░███░░███░░█░██░████░░█░░░░█░░███ ░█░░░░█  █░█ ██░█░░█░███ ░\n' +
		'░█  █░█  █░█░░░░█░░█░█  ░░█  ░░█░ █░█  █░░█░░█░█░░█  █░█░░░░█░░█░█░ █░█░░█░█  ░░\n' +
		'░█░░█░███ ░████░███ ░████░█░░░░███ ░█░░█░███░███░░█░░█░████░█░░█░█░░█░ ██ ░█░░░░\n' +
		'░ ░░ ░   ░░    ░   ░░    ░ ░░░░   ░░ ░░ ░   ░   ░░ ░░ ░    ░ ░░ ░ ░░ ░░  ░░ ░░░░\n' +
		'░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░\n' +
		'\n' +
		'░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░\n' +
		'░░██░░███░░░███░███░█░░█░█░░░█░█░░█░█░░█░█░█░████░░██░░██░░░▐██░░████░█░░░░████░\n' +
		'░█  █░█  █░█   ░ █ ░█░░█░█░░░█░█░░█░█░░█░███░  █ ░█  █░ █░░░   █░   █░█░█░░█   ░\n' +
		'░█░░█░███ ░ ██░░░█░░█░░█░█░░░█░█░░█░ ██ ░ █ ░░█ ░░█░▌█░░█░░░░░█ ░░░██░████░███░░\n' +
		'░█░░█░█  █░░  █░░█░░█░░█░ █░█ ░████░█  █░░█░░█ ░░░█░ █░░█░░░░█ ░░░░ █░   █░   █░\n' +
		'░ ███░█░░█░███ ░░█░░ ██ ░░ █ ░░█  █░█░░█░░█░░████░ ██ ░███░░████░████░░░░█░███ ░\n' +
		'░░   ░ ░░ ░   ░░░ ░░░  ░░░░ ░░░ ░░ ░ ░░ ░░ ░░    ░░  ░░   ░░    ░    ░░░░ ░   ░░\n' +
		'░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░\n' +
		'\n' +
		'░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░\n' +
		'░░███░████░░██░░░██░░░██░░▐██░░░░░░░░░░░░░░░░░░░░░░░░░░░░██░░░▌▐░░░░▌░░░░░█░\n' +
		'░█   ░   █░█  █░█  █░░██░░   █░░░░░░░░█░░░░░░░░░░░░████░█  █░████░░███░█░█ ░\n' +
		'░███░░████░ ██ ░ ███░░██░░░░█ ░░░░░░░███░████░░░░░░    ░█░▌█░ ▌▐ ░█ █ ░ ░█░░\n' +
		'░█  █░ █  ░█  █░░  █░░  ░░░░ ░░░░░░░░ █ ░    ░░░░░░████░█░█ ░████░ ██░░░█ ░░\n' +
		'░ ██ ░█ ░░░ ██ ░░░█ ░░██░░░░█░░░░█░░░░ ░░░░░░░░░░░░    ░ ███░ ▌▐ ░░░▌█░░█░█░\n' +
		'░░  ░░ ░░░░░  ░░░░ ░░░  ░░░░ ░░░░ ░░░░░░░░░░░░████░░░░░░    ░░  ░░███ ░█ ░ ░\n' +
		'░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░    ░░░░░░░░░░░░░░░░   ░░ ░░░░\n' +
		'\n' +
		'░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░░\n' +
		'░░█░░░░░░█░░░█░░░░░░█░░░░░░░░░░░░░░░░░█░░░░█░█░░░\n' +
		'░░█░░░░░█ ░░░ █░░░░█ ░░█░░░░░░░░░░░░░░ ░░░░ ░ ░░░\n' +
		'░█████░█ ░░░░░ █░░░█░░░ ░░░░░░░░░░░░░░░░░░░░░░░░░\n' +
		'░█  █ ░█░░░░░░░█░░█ ░░░░░░░░█░░░░░░░░░░░░░░░░░░░░\n' +
		'░████░░ █░░░░░█ ░░█░░░░█░░░░ ░░░░░░░░░░░░░░░░░░░░\n' +
		'░     ░░ █░░░█ ░░█ ░░░░ ░░░░█░░░░░█░░░░░░░░░░░░░░\n' +
		'░░░░░░░░░ ░░░ ░░░ ░░░░░░░░░░█░░░░█ ░░░░░░░░░░░░░░\n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font shade in all colors`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'shade', '-c', 'red,blue' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m   \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m   \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m   \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m   \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m  \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█ ██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m  \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m  \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m  \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m██\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;0;0;255m░░\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m   \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m    \u001b[38;2;0;0;255m░\u001b[39m   \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m    \u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m   \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;0;0;255m░░\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m   \u001b[38;2;0;0;255m░\u001b[39m   \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;0;0;255m░░\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m    \u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;0;0;255m░░\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;0;0;255m░░\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░  ░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m██\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▐██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m   \u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m  \u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m   \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m   \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m   \u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m██\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m  \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m   \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m   \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m██\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m██\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m   \u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;0;0;255m░░\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m   \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░ ░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░  ░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░ ░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;0;0;255m░░\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;0;0;255m░░\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░ ░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m    \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░  ░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m   \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m    \u001b[38;2;0;0;255m░\u001b[39m    \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m   \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▐██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌▐\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m   \u001b[38;2;0;0;255m░\u001b[39m   \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m   \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m██\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m    \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m▌█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m▌▐\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█ █\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m█\u001b[39m  \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m  \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░  ░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░ ░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m    \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m██\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m██\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m██\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░ ░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m    \u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m▌▐\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m▌█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░  ░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░  ░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░ ░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░  ░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░ ░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░ ░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m    \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░  ░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m███\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m    \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m   \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░ ░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░ ░ ░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░ ░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█  █\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m████\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░ ░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m    \u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░ ░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░ ░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░ ░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m \u001b[38;2;0;0;255m░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;0;0;255m░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;255;0;0m█\u001b[39m \u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\u001b[38;2;0;0;255m░░░░░░\u001b[39m\u001b[38;2;0;0;255m░\u001b[39m\n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font simple`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'simple' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'    _     ___     __   ___    ___   ___    ___   _  _   ___      _   _  _  \n' +
		'   /_\\   | _ )  / __| |   \\  | __| | __|  / __| | || | |_ _|  _ | | | |/ / \n' +
		'  / _ \\  | _ \\ | (__  | |) | | _|  | _|  | (_ | | __ |  | |  | || | | \' <  \n' +
		' /_/ \\_\\ |___/  \\___| |___/  |___| |_|    \\___| |_||_| |___|  \\__/  |_|\\_\\ \n' +
		'\n' +
		'  _      _    _   _  _    ___    ___    ___    ___   ___   _____   _   _  \n' +
		' | |    | \\  / | | \\| |  / _ \\  | _ \\  / _ \\  | _ \\ / __| |_   _| | | | | \n' +
		' | |__  | |\\/| | | .` | | (_) | |  _/ | (_) | |   / \\__ \\   | |   | |_| | \n' +
		' |____| |_|  |_| |_|\\_|  \\___/  |_|    \\__\\_\\ |_|_\\ |___/   |_|    \\___/  \n' +
		'\n' +
		' _    _  __      __ _   _  _    _   ____   __    _   ___   ___   _ _    ___  \n' +
		' \\ \\ / / \\ \\    / / \\ \\/ / \\ \\ / / |_  /  /  \\  / | |_  ) |__ / | | |  | __| \n' +
		'  \\ V /   \\ \\/\\/ /   >  <   \\ V /   / /  | () | | |  / /   |_ \\ |_  _| |__ \\ \n' +
		'   \\_/     \\_/\\_/   /_/\\_\\   |_|   /___|  \\__/  |_| /___| |___/   |_|  |___/ \n' +
		'\n' +
		'   __   ____   ___   ___   _   ___         _                 ___   / __ \\  \n' +
		'  / /  |__  | ( _ ) / _ \\ | | |__ \\      _| |_   ___        |___| / / _` | \n' +
		' / _ \\   / /  / _ \\ \\_, / |_|  /_/      |_   _| |___|  ___   ___  \\ \\__,_| \n' +
		' \\___/  /_/   \\___/  /_/  (_) (_)   (_)   |_|         |___| |___|  \\____/  \n' +
		'\n' +
		'  _| | |_   ||_     __   __       / / \\ \\     __             |-| |-||-| \n' +
		' |_  .  _| (_-< (_)/ /  / _|___  | |   | |   / / (_) (_)     |/  |/ |/  \n' +
		' |_     _| / _/   / /_  > _|_ _| | |   | |  / /      ( ) ( )            \n' +
		'   |_|_|    ||   /_/(_) \\_____|   \\_\\ /_/  /_/   (_) |/  |/             \n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font simple in all colors`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'simple', '-c', 'red' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   __ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _  _ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m    _ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _  _ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  /_\\  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| _ )\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m / __|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|   \\ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| __|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| __|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m / __|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| || |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|_ _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _ | |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| |/ /\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m / _ \\ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| _ \\\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| (__ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| |) |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| _| \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| _| \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| (_ |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| __ |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m | | \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| || |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| \' < \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m/_/ \\_\\\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|___/\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \\___|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|___/ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|___|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \\___|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|_||_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|___|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \\__/ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|_|\\_\\\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _    _ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _  _ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  ___  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  ___  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _____ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _   _ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| |   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| \\  / |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| \\| |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m / _ \\ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| _ \\\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m / _ \\ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| _ \\\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m/ __|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|_   _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| | | |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| |__ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| |\\/| |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| .` |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| (_) |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|  _/\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| (_) |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|   /\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m\\__ \\\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  | |  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| |_| |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|____|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|_|  |_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|_|\\_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \\___/ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \\__\\_\\\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|_|_\\\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|___/\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  |_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \\___/ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m_    _ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m__      __\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m_   _ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m_    _ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ____\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  __  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _ _  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m\\ \\ / /\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m\\ \\    / /\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m\\ \\/ /\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m\\ \\ / /\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|_  /\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m /  \\ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m/ |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|_  )\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|__ /\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| | | \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| __|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \\ V / \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \\ \\/\\/ / \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m >  < \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \\ V / \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m / / \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| () |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m / / \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m |_ \\\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|_  _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|__ \\\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  \\_/  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  \\_/\\_/  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m/_/\\_\\\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  |_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m/___|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \\__/ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m/___|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|___/\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  |_| \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|___/\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  __ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ____ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m / __ \\ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m / / \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|__  |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m( _ )\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m/ _ \\\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|__ \\\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _| |_ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|___|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m/ / _` |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m/ _ \\\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  / / \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m/ _ \\\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m\\_, /\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m /_/ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|_   _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|___|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m\\ \\__,_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m\\___/\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m /_/  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m\\___/\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m /_/ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m(_)\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m(_)  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m(_)\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  |_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|___|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|___|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \\____/ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _| | |_ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ||_\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m    __ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m __     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m / /\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m\\ \\ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   __\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|-|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|-||-|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|_  .  _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m(_-<\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m(_)/ / \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m/ _|___ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| | \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m | |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  / /\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m(_)\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m(_)\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|/ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|/ |/ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|_     _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m/ _/\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  / /_ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m> _|_ _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m| | \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m | |\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m / / \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m( )\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m( )\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  |_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m || \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m /_/(_)\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m\\_____| \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \\_\\\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m/_/ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m/_/  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m(_)\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|/ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m|/ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font simple3d`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'simple3d' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'           __                 __               ___     __      __              \n' +
		'   __     /\\ \\        ___    /\\ \\      __    /\'___\\  / _ `\\   /\\ \\        __   \n' +
		' /\'__`\\   \\ \\ \\____  /\'___\\  \\_\\ \\   / ,.`\\ /\\ \\__/ /\\ \\_\\ \\  \\ \\ \\___   /\\_\\  \n' +
		'/\\ \\_\\.\\_  \\ \\  ,. \\/\\ \\__/ /\\ ,. \\ /\\  __/ \\ \\ ,__\\\\ \\____ \\  \\ \\  _ `\\ \\/\\ \\ \n' +
		'\\ \\__/.\\_\\  \\ \\____/\\ \\____\\\\ \\____\\\\ \\____\\ \\ \\_\\_/ \\/___/\\ \\  \\ \\_\\ \\_\\ \\ \\ \\\n' +
		' \\/__/\\/_/   \\/___/  \\/____/ \\/___ / \\/____/  \\/_/     /\\____/   \\/_/\\/_/  \\/_/\n' +
		'                                                       \\_/__/                  ' +
		'\n\n' +
		'  __      __  __     ___                                                      \n' +
		' /\\_\\    /\\ \\/  \\   /\\_ \\      ___ ___      ___      ___    _____      __     \n' +
		' \\/\\ \\   \\ \\    <   \\//\\ \\   /\' __` __`\\  /\' _ `\\   / __`\\ /\\ \'__`\\  /\'__`\\   \n' +
		' _\\ \\ \\   \\ \\  ^  \\   \\_\\ \\_ /\\ \\/\\ \\/\\ \\ /\\ \\/\\ \\ /\\ \\_\\ \\\\ \\ \\_\\ \\/\\ \\L\\ \\  \n' +
		'/\\ \\_\\ \\   \\ \\_\\ \\_\\  /\\____\\\\ \\_\\ \\_\\ \\_\\\\ \\_\\ \\_\\\\ \\____/ \\ \\ ,__/\\ \\___, \\ \n' +
		'\\ \\____/    \\/_/\\/_/  \\/____/ \\/_/\\/_/\\/_/ \\/_/\\/_/ \\/___/   \\ \\ \\/  \\/___/\\_\\\n' +
		' \\/___/                                                       \\/_/        \\/_/' +
		'\n\n                __                                                       \n' +
		' _ __    ____  /\\ \\__    __  __   __  __  __  __  __   __  _    __  __   \n' +
		'/\\` __\\ / ,__\\ \\ \\ ,_\\  /\\ \\/\\ \\ /\\ \\/\\ \\/\\ \\/\\ \\/\\ \\ /\\ \\/\'\\  /\\ \\_\\ \\  \n' +
		'\\ \\ \\/ /\\__, `\\ \\ \\ \\/  \\ \\ \\_\\ \\\\ \\ \\/ |\\ \\ \\_/ \\_/ \\\\/>  </  \\/`____ \\ \n' +
		' \\ \\_\\ \\/\\____/  \\ \\ \\_  \\ \\____/ \\ \\___/ \\ \\___^___/\' /\\_/\\_\\  `/___/> \\\n' +
		'  \\/_/  \\/___/    \\ \\__\\  \\/___/   \\/__/   \\/__//__/   \\//\\/_/     /\\___/\n' +
		'                   \\/__/                                           \\/__/ ' +
		'\n\n            __        _        ___        __      __ __       ______    \n' +
		' ____     /\'__`\\    /\' \\     /\'___`\\    /\'__`\\   /\\ \\\\ \\     /\\  ___\\   \n' +
		'/\\_ ,`\\  /\\ \\/\\ \\  /\\_, \\   /\\_\\ /\\ \\  /\\_\\L\\ \\  \\ \\ \\\\ \\    \\ \\ \\__/   \n' +
		'\\/_/  /_ \\ \\ \\ \\ \\ \\/_/\\ \\  \\/_/// /__ \\/_/_\\_<_  \\ \\ \\\\ \\_   \\ \\___``\\ \n' +
		'  /\\____\\ \\ \\ \\_\\ \\   \\ \\ \\    // /_\\ \\  /\\ \\L\\ \\  \\ \\__ ,__\\  \\/\\ \\L\\ \\\n' +
		'  \\/____/  \\ \\____/    \\ \\_\\  /\\______/  \\ \\____/   \\/_/\\_\\_/   \\ \\____/\n' +
		'            \\/___/      \\/_/  \\/_____/    \\/___/       \\/_/      \\/___/ ' +
		'\n\n  ____     ________    __        __       __        _          __               \n' +
		' /\'___\\   /\\____   \\ /\' _`\\    /\'_ `\\    /\\ \\     /\'_`\\       /\\ \\              \n' +
		'/\\ \\__/   \\/___/\' /\'/\\ \\L\\ \\  /\\ \\L\\ \\   \\ \\ \\   /\\_\\/\\`\\     \\_\\ \\___  _______ \n' +
		'\\ \\  _``\\     /\' /\' \\/_> _ <_ \\ \\___, \\   \\ \\ \\  \\/_//\'/\'    /\\___  __\\/\\______\\\n' +
		' \\ \\ \\L\\ \\   /\' /\'    /\\ \\L\\ \\ \\/__,/\\ \\   \\ \\_\\    /\\_\\  __ \\/__/\\ \\_/\\/______/\n' +
		'  \\ \\____/  /\\_/      \\ \\____/      \\ \\_\\   \\/\\_\\   \\/\\_\\/\\_\\    \\ \\_\\          \n' +
		'   \\/___/   \\//        \\/___/        \\/_/    \\/_/    \\/_/\\/_/     \\/_/          ' +
		'\n\n                        __        __ __          _      __    __       ____     \n' +
		'           _______     /\'_`\\_    _\\ \\\\ \\__     /|_\\_   /\\_\\  /\\_\\    /|  _ \\    \n' +
		'          /\\______\\   /\'/\'_` \\  /\\__  _  _\\   /\'  _ `\\ \\/_/ / / /    |/\\ ` |    \n' +
		'          \\/______/_ /\\ \\ \\L\\ \\ \\/_L\\ \\\\ \\L_  \\ \\___  \\    / / /     \\ / __`\\/\\ \n' +
		'  _______   /\\______\\\\ \\ `\\__,_\\  /\\_   _  _\\  \\ `\\_ _/   / / /  __  /|  \\L>  <_\n' +
		' /\\______\\  \\/______/ \\ `\\_____\\  \\/_/\\_\\\\_\\/   `\\_/\\_\\  / / /  /\\_\\ | \\_____/\\/\n' +
		' \\/______/             `\\/_____/     \\/_//_/       \\/_/  \\/_/   \\/_/  \\/____/\\/ ' +
		'\n\n   _      __          __                    _    _   _  \n' +
		' /\' \\    /\\ `\\       /\\_\\ __    __        /\\ \\ /\\ \\/\\ \\ \n' +
		'/\\ ,/    \\`\\  \\     / / //\\_\\  /\\_\\       \\ \\/ \\ \\/\\ \\/ \n' +
		'\\ \\ \\     `\\`\\ \\   / / / \\/_/_ \\/_/_    _  \\/   \\/  \\/  \n' +
		' \\ \\ `\\    `\\/\' \\ / / /    /\\_\\  /\\ \\ /\\ \\              \n' +
		'  \\ `\\__\\   /\\__// / /     \\/_/  \\ \\/ \\ \\/              \n' +
		'   `\\/_/    \\/_/ \\/_/             \\/   \\/               \n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font simple3d in all colors`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'simple3d', '-c', 'red' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'\u001b[38;2;255;0;0m          \u001b[39m\u001b[38;2;255;0;0m __       \u001b[39m\u001b[38;2;255;0;0m        \u001b[39m\u001b[38;2;255;0;0m  __    \u001b[39m\u001b[38;2;255;0;0m        \u001b[39m\u001b[38;2;255;0;0m   ___  \u001b[39m\u001b[38;2;255;0;0m   __     \u001b[39m\u001b[38;2;255;0;0m __        \u001b[39m\u001b[38;2;255;0;0m      \u001b[39m\n\u001b[38;2;255;0;0m   __     \u001b[39m\u001b[38;2;255;0;0m/\\ \\      \u001b[39m\u001b[38;2;255;0;0m  ___   \u001b[39m\u001b[38;2;255;0;0m /\\ \\   \u001b[39m\u001b[38;2;255;0;0m   __   \u001b[39m\u001b[38;2;255;0;0m /\'___\\ \u001b[39m\u001b[38;2;255;0;0m / _ `\\   \u001b[39m\u001b[38;2;255;0;0m/\\ \\       \u001b[39m\u001b[38;2;255;0;0m __   \u001b[39m\n\u001b[38;2;255;0;0m /\'__`\\   \u001b[39m\u001b[38;2;255;0;0m\\ \\ \\____ \u001b[39m\u001b[38;2;255;0;0m /\'___\\ \u001b[39m\u001b[38;2;255;0;0m \\_\\ \\  \u001b[39m\u001b[38;2;255;0;0m / ,.`\\ \u001b[39m\u001b[38;2;255;0;0m/\\ \\__/ \u001b[39m\u001b[38;2;255;0;0m/\\ \\_\\ \\  \u001b[39m\u001b[38;2;255;0;0m\\ \\ \\___   \u001b[39m\u001b[38;2;255;0;0m/\\_\\  \u001b[39m\n\u001b[38;2;255;0;0m/\\ \\_\\.\\_ \u001b[39m\u001b[38;2;255;0;0m \\ \\  ,. \\\u001b[39m\u001b[38;2;255;0;0m/\\ \\__/ \u001b[39m\u001b[38;2;255;0;0m/\\ ,. \\ \u001b[39m\u001b[38;2;255;0;0m/\\  __/ \u001b[39m\u001b[38;2;255;0;0m\\ \\ ,__\\\u001b[39m\u001b[38;2;255;0;0m\\ \\____ \\ \u001b[39m\u001b[38;2;255;0;0m \\ \\  _ `\\ \u001b[39m\u001b[38;2;255;0;0m\\/\\ \\ \u001b[39m\n\u001b[38;2;255;0;0m\\ \\__/.\\_\\\u001b[39m\u001b[38;2;255;0;0m  \\ \\____/\u001b[39m\u001b[38;2;255;0;0m\\ \\____\\\u001b[39m\u001b[38;2;255;0;0m\\ \\____\\\u001b[39m\u001b[38;2;255;0;0m\\ \\____\\\u001b[39m\u001b[38;2;255;0;0m \\ \\_\\_/\u001b[39m\u001b[38;2;255;0;0m \\/___/\\ \\\u001b[39m\u001b[38;2;255;0;0m  \\ \\_\\ \\_\\\u001b[39m\u001b[38;2;255;0;0m \\ \\ \\\u001b[39m\n\u001b[38;2;255;0;0m \\/__/\\/_/\u001b[39m\u001b[38;2;255;0;0m   \\/___/ \u001b[39m\u001b[38;2;255;0;0m \\/____/\u001b[39m\u001b[38;2;255;0;0m \\/___ /\u001b[39m\u001b[38;2;255;0;0m \\/____/\u001b[39m\u001b[38;2;255;0;0m  \\/_/  \u001b[39m\u001b[38;2;255;0;0m   /\\____/\u001b[39m\u001b[38;2;255;0;0m   \\/_/\\/_/\u001b[39m\u001b[38;2;255;0;0m  \\/_/\u001b[39m\n\u001b[38;2;255;0;0m          \u001b[39m\u001b[38;2;255;0;0m          \u001b[39m\u001b[38;2;255;0;0m        \u001b[39m\u001b[38;2;255;0;0m        \u001b[39m\u001b[38;2;255;0;0m        \u001b[39m\u001b[38;2;255;0;0m        \u001b[39m\u001b[38;2;255;0;0m   \\_/__/ \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m      \u001b[39m\n\n\u001b[38;2;255;0;0m  __    \u001b[39m\u001b[38;2;255;0;0m  __  __    \u001b[39m\u001b[38;2;255;0;0m ___     \u001b[39m\u001b[38;2;255;0;0m             \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m        \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m          \u001b[39m\n\u001b[38;2;255;0;0m /\\_\\   \u001b[39m\u001b[38;2;255;0;0m /\\ \\/  \\   \u001b[39m\u001b[38;2;255;0;0m/\\_ \\    \u001b[39m\u001b[38;2;255;0;0m  ___ ___    \u001b[39m\u001b[38;2;255;0;0m  ___    \u001b[39m\u001b[38;2;255;0;0m  ___   \u001b[39m\u001b[38;2;255;0;0m _____   \u001b[39m\u001b[38;2;255;0;0m   __     \u001b[39m\n\u001b[38;2;255;0;0m \\/\\ \\  \u001b[39m\u001b[38;2;255;0;0m \\ \\    <   \u001b[39m\u001b[38;2;255;0;0m\\//\\ \\   \u001b[39m\u001b[38;2;255;0;0m/\' __` __`\\  \u001b[39m\u001b[38;2;255;0;0m/\' _ `\\  \u001b[39m\u001b[38;2;255;0;0m / __`\\ \u001b[39m\u001b[38;2;255;0;0m/\\ \'__`\\ \u001b[39m\u001b[38;2;255;0;0m /\'__`\\   \u001b[39m\n\u001b[38;2;255;0;0m _\\ \\ \\ \u001b[39m\u001b[38;2;255;0;0m  \\ \\  ^  \\ \u001b[39m\u001b[38;2;255;0;0m  \\_\\ \\_ \u001b[39m\u001b[38;2;255;0;0m/\\ \\/\\ \\/\\ \\ \u001b[39m\u001b[38;2;255;0;0m/\\ \\/\\ \\ \u001b[39m\u001b[38;2;255;0;0m/\\ \\_\\ \\\u001b[39m\u001b[38;2;255;0;0m\\ \\ \\_\\ \\\u001b[39m\u001b[38;2;255;0;0m/\\ \\L\\ \\  \u001b[39m\n\u001b[38;2;255;0;0m/\\ \\_\\ \\\u001b[39m\u001b[38;2;255;0;0m   \\ \\_\\ \\_\\\u001b[39m\u001b[38;2;255;0;0m  /\\____\\\u001b[39m\u001b[38;2;255;0;0m\\ \\_\\ \\_\\ \\_\\\u001b[39m\u001b[38;2;255;0;0m\\ \\_\\ \\_\\\u001b[39m\u001b[38;2;255;0;0m\\ \\____/\u001b[39m\u001b[38;2;255;0;0m \\ \\ ,__/\u001b[39m\u001b[38;2;255;0;0m\\ \\___, \\ \u001b[39m\n\u001b[38;2;255;0;0m\\ \\____/\u001b[39m\u001b[38;2;255;0;0m    \\/_/\\/_/\u001b[39m\u001b[38;2;255;0;0m  \\/____/\u001b[39m\u001b[38;2;255;0;0m \\/_/\\/_/\\/_/\u001b[39m\u001b[38;2;255;0;0m \\/_/\\/_/\u001b[39m\u001b[38;2;255;0;0m \\/___/ \u001b[39m\u001b[38;2;255;0;0m  \\ \\ \\/ \u001b[39m\u001b[38;2;255;0;0m \\/___/\\_\\\u001b[39m\n\u001b[38;2;255;0;0m \\/___/ \u001b[39m\u001b[38;2;255;0;0m            \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m             \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m        \u001b[39m\u001b[38;2;255;0;0m   \\/_/  \u001b[39m\u001b[38;2;255;0;0m      \\/_/\u001b[39m\n\n\u001b[38;2;255;0;0m       \u001b[39m\u001b[38;2;255;0;0m        \u001b[39m\u001b[38;2;255;0;0m __      \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m        \u001b[39m\u001b[38;2;255;0;0m             \u001b[39m\u001b[38;2;255;0;0m        \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\n\u001b[38;2;255;0;0m _ __  \u001b[39m\u001b[38;2;255;0;0m  ____  \u001b[39m\u001b[38;2;255;0;0m/\\ \\__   \u001b[39m\u001b[38;2;255;0;0m __  __  \u001b[39m\u001b[38;2;255;0;0m __  __ \u001b[39m\u001b[38;2;255;0;0m __  __  __  \u001b[39m\u001b[38;2;255;0;0m __  _  \u001b[39m\u001b[38;2;255;0;0m  __  __   \u001b[39m\n\u001b[38;2;255;0;0m/\\` __\\\u001b[39m\u001b[38;2;255;0;0m / ,__\\ \u001b[39m\u001b[38;2;255;0;0m\\ \\ ,_\\  \u001b[39m\u001b[38;2;255;0;0m/\\ \\/\\ \\ \u001b[39m\u001b[38;2;255;0;0m/\\ \\/\\ \\\u001b[39m\u001b[38;2;255;0;0m/\\ \\/\\ \\/\\ \\ \u001b[39m\u001b[38;2;255;0;0m/\\ \\/\'\\ \u001b[39m\u001b[38;2;255;0;0m /\\ \\_\\ \\  \u001b[39m\n\u001b[38;2;255;0;0m\\ \\ \\/ \u001b[39m\u001b[38;2;255;0;0m/\\__, `\\\u001b[39m\u001b[38;2;255;0;0m \\ \\ \\/  \u001b[39m\u001b[38;2;255;0;0m\\ \\ \\_\\ \\\u001b[39m\u001b[38;2;255;0;0m\\ \\ \\/ |\u001b[39m\u001b[38;2;255;0;0m\\ \\ \\_/ \\_/ \\\u001b[39m\u001b[38;2;255;0;0m\\/>  </ \u001b[39m\u001b[38;2;255;0;0m \\/`____ \\ \u001b[39m\n\u001b[38;2;255;0;0m \\ \\_\\ \u001b[39m\u001b[38;2;255;0;0m\\/\\____/\u001b[39m\u001b[38;2;255;0;0m  \\ \\ \\_ \u001b[39m\u001b[38;2;255;0;0m \\ \\____/\u001b[39m\u001b[38;2;255;0;0m \\ \\___/\u001b[39m\u001b[38;2;255;0;0m \\ \\___^___/\'\u001b[39m\u001b[38;2;255;0;0m /\\_/\\_\\\u001b[39m\u001b[38;2;255;0;0m  `/___/> \\\u001b[39m\n\u001b[38;2;255;0;0m  \\/_/ \u001b[39m\u001b[38;2;255;0;0m \\/___/ \u001b[39m\u001b[38;2;255;0;0m   \\ \\__\\\u001b[39m\u001b[38;2;255;0;0m  \\/___/ \u001b[39m\u001b[38;2;255;0;0m  \\/__/ \u001b[39m\u001b[38;2;255;0;0m  \\/__//__/  \u001b[39m\u001b[38;2;255;0;0m \\//\\/_/\u001b[39m\u001b[38;2;255;0;0m     /\\___/\u001b[39m\n\u001b[38;2;255;0;0m       \u001b[39m\u001b[38;2;255;0;0m        \u001b[39m\u001b[38;2;255;0;0m    \\/__/\u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m        \u001b[39m\u001b[38;2;255;0;0m             \u001b[39m\u001b[38;2;255;0;0m        \u001b[39m\u001b[38;2;255;0;0m     \\/__/ \u001b[39m\n\n\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m   __     \u001b[39m\u001b[38;2;255;0;0m   _     \u001b[39m\u001b[38;2;255;0;0m   ___     \u001b[39m\u001b[38;2;255;0;0m   __     \u001b[39m\u001b[38;2;255;0;0m __ __      \u001b[39m\u001b[38;2;255;0;0m ______    \u001b[39m\n\u001b[38;2;255;0;0m ____    \u001b[39m\u001b[38;2;255;0;0m /\'__`\\   \u001b[39m\u001b[38;2;255;0;0m /\' \\    \u001b[39m\u001b[38;2;255;0;0m /\'___`\\   \u001b[39m\u001b[38;2;255;0;0m /\'__`\\   \u001b[39m\u001b[38;2;255;0;0m/\\ \\\\ \\     \u001b[39m\u001b[38;2;255;0;0m/\\  ___\\   \u001b[39m\n\u001b[38;2;255;0;0m/\\_ ,`\\  \u001b[39m\u001b[38;2;255;0;0m/\\ \\/\\ \\  \u001b[39m\u001b[38;2;255;0;0m/\\_, \\   \u001b[39m\u001b[38;2;255;0;0m/\\_\\ /\\ \\  \u001b[39m\u001b[38;2;255;0;0m/\\_\\L\\ \\  \u001b[39m\u001b[38;2;255;0;0m\\ \\ \\\\ \\    \u001b[39m\u001b[38;2;255;0;0m\\ \\ \\__/   \u001b[39m\n\u001b[38;2;255;0;0m\\/_/  /_ \u001b[39m\u001b[38;2;255;0;0m\\ \\ \\ \\ \\ \u001b[39m\u001b[38;2;255;0;0m\\/_/\\ \\  \u001b[39m\u001b[38;2;255;0;0m\\/_/// /__ \u001b[39m\u001b[38;2;255;0;0m\\/_/_\\_<_ \u001b[39m\u001b[38;2;255;0;0m \\ \\ \\\\ \\_  \u001b[39m\u001b[38;2;255;0;0m \\ \\___``\\ \u001b[39m\n\u001b[38;2;255;0;0m  /\\____\\\u001b[39m\u001b[38;2;255;0;0m \\ \\ \\_\\ \\\u001b[39m\u001b[38;2;255;0;0m   \\ \\ \\ \u001b[39m\u001b[38;2;255;0;0m   // /_\\ \\\u001b[39m\u001b[38;2;255;0;0m  /\\ \\L\\ \\\u001b[39m\u001b[38;2;255;0;0m  \\ \\__ ,__\\\u001b[39m\u001b[38;2;255;0;0m  \\/\\ \\L\\ \\\u001b[39m\n\u001b[38;2;255;0;0m  \\/____/\u001b[39m\u001b[38;2;255;0;0m  \\ \\____/\u001b[39m\u001b[38;2;255;0;0m    \\ \\_\\\u001b[39m\u001b[38;2;255;0;0m  /\\______/\u001b[39m\u001b[38;2;255;0;0m  \\ \\____/\u001b[39m\u001b[38;2;255;0;0m   \\/_/\\_\\_/\u001b[39m\u001b[38;2;255;0;0m   \\ \\____/\u001b[39m\n\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m   \\/___/ \u001b[39m\u001b[38;2;255;0;0m     \\/_/\u001b[39m\u001b[38;2;255;0;0m  \\/_____/ \u001b[39m\u001b[38;2;255;0;0m   \\/___/ \u001b[39m\u001b[38;2;255;0;0m      \\/_/  \u001b[39m\u001b[38;2;255;0;0m    \\/___/ \u001b[39m\n\n\u001b[38;2;255;0;0m  ____    \u001b[39m\u001b[38;2;255;0;0m ________ \u001b[39m\u001b[38;2;255;0;0m   __     \u001b[39m\u001b[38;2;255;0;0m   __      \u001b[39m\u001b[38;2;255;0;0m __     \u001b[39m\u001b[38;2;255;0;0m   _    \u001b[39m\u001b[38;2;255;0;0m    \u001b[39m\u001b[38;2;255;0;0m  __      \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\n\u001b[38;2;255;0;0m /\'___\\   \u001b[39m\u001b[38;2;255;0;0m/\\____   \\\u001b[39m\u001b[38;2;255;0;0m /\' _`\\   \u001b[39m\u001b[38;2;255;0;0m /\'_ `\\    \u001b[39m\u001b[38;2;255;0;0m/\\ \\    \u001b[39m\u001b[38;2;255;0;0m /\'_`\\  \u001b[39m\u001b[38;2;255;0;0m    \u001b[39m\u001b[38;2;255;0;0m /\\ \\     \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\n\u001b[38;2;255;0;0m/\\ \\__/   \u001b[39m\u001b[38;2;255;0;0m\\/___/\' /\'\u001b[39m\u001b[38;2;255;0;0m/\\ \\L\\ \\  \u001b[39m\u001b[38;2;255;0;0m/\\ \\L\\ \\   \u001b[39m\u001b[38;2;255;0;0m\\ \\ \\   \u001b[39m\u001b[38;2;255;0;0m/\\_\\/\\`\\\u001b[39m\u001b[38;2;255;0;0m    \u001b[39m\u001b[38;2;255;0;0m \\_\\ \\___ \u001b[39m\u001b[38;2;255;0;0m _______ \u001b[39m\n\u001b[38;2;255;0;0m\\ \\  _``\\ \u001b[39m\u001b[38;2;255;0;0m    /\' /\' \u001b[39m\u001b[38;2;255;0;0m\\/_> _ <_ \u001b[39m\u001b[38;2;255;0;0m\\ \\___, \\  \u001b[39m\u001b[38;2;255;0;0m \\ \\ \\  \u001b[39m\u001b[38;2;255;0;0m\\/_//\'/\'\u001b[39m\u001b[38;2;255;0;0m    \u001b[39m\u001b[38;2;255;0;0m/\\___  __\\\u001b[39m\u001b[38;2;255;0;0m/\\______\\\u001b[39m\n\u001b[38;2;255;0;0m \\ \\ \\L\\ \\\u001b[39m\u001b[38;2;255;0;0m   /\' /\'  \u001b[39m\u001b[38;2;255;0;0m  /\\ \\L\\ \\\u001b[39m\u001b[38;2;255;0;0m \\/__,/\\ \\ \u001b[39m\u001b[38;2;255;0;0m  \\ \\_\\ \u001b[39m\u001b[38;2;255;0;0m   /\\_\\ \u001b[39m\u001b[38;2;255;0;0m __ \u001b[39m\u001b[38;2;255;0;0m\\/__/\\ \\_/\u001b[39m\u001b[38;2;255;0;0m\\/______/\u001b[39m\n\u001b[38;2;255;0;0m  \\ \\____/\u001b[39m\u001b[38;2;255;0;0m  /\\_/    \u001b[39m\u001b[38;2;255;0;0m  \\ \\____/\u001b[39m\u001b[38;2;255;0;0m      \\ \\_\\\u001b[39m\u001b[38;2;255;0;0m   \\/\\_\\\u001b[39m\u001b[38;2;255;0;0m   \\/\\_\\\u001b[39m\u001b[38;2;255;0;0m/\\_\\\u001b[39m\u001b[38;2;255;0;0m    \\ \\_\\ \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\n\u001b[38;2;255;0;0m   \\/___/ \u001b[39m\u001b[38;2;255;0;0m  \\//     \u001b[39m\u001b[38;2;255;0;0m   \\/___/ \u001b[39m\u001b[38;2;255;0;0m       \\/_/\u001b[39m\u001b[38;2;255;0;0m    \\/_/\u001b[39m\u001b[38;2;255;0;0m    \\/_/\u001b[39m\u001b[38;2;255;0;0m\\/_/\u001b[39m\u001b[38;2;255;0;0m     \\/_/ \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\n\n\u001b[38;2;255;0;0m          \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m   __      \u001b[39m\u001b[38;2;255;0;0m  __ __      \u001b[39m\u001b[38;2;255;0;0m    _     \u001b[39m\u001b[38;2;255;0;0m __    __    \u001b[39m\u001b[38;2;255;0;0m   ____     \u001b[39m\n\u001b[38;2;255;0;0m          \u001b[39m\u001b[38;2;255;0;0m _______   \u001b[39m\u001b[38;2;255;0;0m  /\'_`\\_   \u001b[39m\u001b[38;2;255;0;0m _\\ \\\\ \\__   \u001b[39m\u001b[38;2;255;0;0m  /|_\\_   \u001b[39m\u001b[38;2;255;0;0m/\\_\\  /\\_\\   \u001b[39m\u001b[38;2;255;0;0m /|  _ \\    \u001b[39m\n\u001b[38;2;255;0;0m          \u001b[39m\u001b[38;2;255;0;0m/\\______\\  \u001b[39m\u001b[38;2;255;0;0m /\'/\'_` \\  \u001b[39m\u001b[38;2;255;0;0m/\\__  _  _\\  \u001b[39m\u001b[38;2;255;0;0m /\'  _ `\\ \u001b[39m\u001b[38;2;255;0;0m\\/_/ / / /   \u001b[39m\u001b[38;2;255;0;0m |/\\ ` |    \u001b[39m\n\u001b[38;2;255;0;0m          \u001b[39m\u001b[38;2;255;0;0m\\/______/_ \u001b[39m\u001b[38;2;255;0;0m/\\ \\ \\L\\ \\ \u001b[39m\u001b[38;2;255;0;0m\\/_L\\ \\\\ \\L_ \u001b[39m\u001b[38;2;255;0;0m \\ \\___  \\\u001b[39m\u001b[38;2;255;0;0m    / / /    \u001b[39m\u001b[38;2;255;0;0m \\ / __`\\/\\ \u001b[39m\n\u001b[38;2;255;0;0m  _______ \u001b[39m\u001b[38;2;255;0;0m  /\\______\\\u001b[39m\u001b[38;2;255;0;0m\\ \\ `\\__,_\\\u001b[39m\u001b[38;2;255;0;0m  /\\_   _  _\\\u001b[39m\u001b[38;2;255;0;0m  \\ `\\_ _/\u001b[39m\u001b[38;2;255;0;0m   / / /  __ \u001b[39m\u001b[38;2;255;0;0m /|  \\L>  <_\u001b[39m\n\u001b[38;2;255;0;0m /\\______\\\u001b[39m\u001b[38;2;255;0;0m  \\/______/\u001b[39m\u001b[38;2;255;0;0m \\ `\\_____\\\u001b[39m\u001b[38;2;255;0;0m  \\/_/\\_\\\\_\\/\u001b[39m\u001b[38;2;255;0;0m   `\\_/\\_\\\u001b[39m\u001b[38;2;255;0;0m  / / /  /\\_\\\u001b[39m\u001b[38;2;255;0;0m | \\_____/\\/\u001b[39m\n\u001b[38;2;255;0;0m \\/______/\u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m  `\\/_____/\u001b[39m\u001b[38;2;255;0;0m     \\/_//_/ \u001b[39m\u001b[38;2;255;0;0m      \\/_/\u001b[39m\u001b[38;2;255;0;0m  \\/_/   \\/_/\u001b[39m\u001b[38;2;255;0;0m  \\/____/\\/ \u001b[39m\n\n\u001b[38;2;255;0;0m   _     \u001b[39m\u001b[38;2;255;0;0m __     \u001b[39m\u001b[38;2;255;0;0m     __ \u001b[39m\u001b[38;2;255;0;0m      \u001b[39m\u001b[38;2;255;0;0m      \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m  _  \u001b[39m\u001b[38;2;255;0;0m  _   _  \u001b[39m\n\u001b[38;2;255;0;0m /\' \\    \u001b[39m\u001b[38;2;255;0;0m/\\ `\\   \u001b[39m\u001b[38;2;255;0;0m    /\\_\\\u001b[39m\u001b[38;2;255;0;0m __   \u001b[39m\u001b[38;2;255;0;0m __   \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m/\\ \\ \u001b[39m\u001b[38;2;255;0;0m/\\ \\/\\ \\ \u001b[39m\n\u001b[38;2;255;0;0m/\\ ,/    \u001b[39m\u001b[38;2;255;0;0m\\`\\  \\  \u001b[39m\u001b[38;2;255;0;0m   / / /\u001b[39m\u001b[38;2;255;0;0m/\\_\\  \u001b[39m\u001b[38;2;255;0;0m/\\_\\  \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m\\ \\/ \u001b[39m\u001b[38;2;255;0;0m\\ \\/\\ \\/ \u001b[39m\n\u001b[38;2;255;0;0m\\ \\ \\    \u001b[39m\u001b[38;2;255;0;0m `\\`\\ \\ \u001b[39m\u001b[38;2;255;0;0m  / / / \u001b[39m\u001b[38;2;255;0;0m\\/_/_ \u001b[39m\u001b[38;2;255;0;0m\\/_/_ \u001b[39m\u001b[38;2;255;0;0m   _ \u001b[39m\u001b[38;2;255;0;0m \\/  \u001b[39m\u001b[38;2;255;0;0m \\/  \\/  \u001b[39m\n\u001b[38;2;255;0;0m \\ \\ `\\  \u001b[39m\u001b[38;2;255;0;0m  `\\/\' \\\u001b[39m\u001b[38;2;255;0;0m / / /  \u001b[39m\u001b[38;2;255;0;0m  /\\_\\\u001b[39m\u001b[38;2;255;0;0m  /\\ \\\u001b[39m\u001b[38;2;255;0;0m /\\ \\\u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\n\u001b[38;2;255;0;0m  \\ `\\__\\\u001b[39m\u001b[38;2;255;0;0m   /\\__/\u001b[39m\u001b[38;2;255;0;0m/ / /   \u001b[39m\u001b[38;2;255;0;0m  \\/_/\u001b[39m\u001b[38;2;255;0;0m  \\ \\/\u001b[39m\u001b[38;2;255;0;0m \\ \\/\u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\n\u001b[38;2;255;0;0m   `\\/_/ \u001b[39m\u001b[38;2;255;0;0m   \\/_/ \u001b[39m\u001b[38;2;255;0;0m\\/_/    \u001b[39m\u001b[38;2;255;0;0m      \u001b[39m\u001b[38;2;255;0;0m   \\/ \u001b[39m\u001b[38;2;255;0;0m  \\/ \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font simpleBlock`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'simpleBlock' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'                                                                       \n' +
		'    _|_|    _|_|_|      _|_|_|  _|_|_|    _|_|_|_|  _|_|_|_|    _|_|_| \n' +
		'  _|    _|  _|    _|  _|        _|    _|  _|        _|        _|       \n' +
		'  _|_|_|_|  _|_|_|    _|        _|    _|  _|_|_|    _|_|_|    _|  _|_| \n' +
		'  _|    _|  _|    _|  _|        _|    _|  _|        _|        _|    _| \n' +
		'  _|    _|  _|_|_|      _|_|_|  _|_|_|    _|_|_|_|  _|          _|_|_| \n' +
		'                                                                       \n' +
		'\n' +
		'                                                                         \n' +
		'  _|    _|  _|_|_|        _|  _|    _|  _|        _|      _|  _|      _| \n' +
		'  _|    _|    _|          _|  _|  _|    _|        _|_|  _|_|  _|_|    _| \n' +
		'  _|_|_|_|    _|          _|  _|_|      _|        _|  _|  _|  _|  _|  _| \n' +
		'  _|    _|    _|    _|    _|  _|  _|    _|        _|      _|  _|    _|_| \n' +
		'  _|    _|  _|_|_|    _|_|    _|    _|  _|_|_|_|  _|      _|  _|      _| \n' +
		'                                                                         \n' +
		'\n' +
		'                                                                           \n' +
		'    _|_|    _|_|_|      _|_|      _|_|_|      _|_|_|  _|_|_|_|_|  _|    _| \n' +
		'  _|    _|  _|    _|  _|    _|    _|    _|  _|            _|      _|    _| \n' +
		'  _|    _|  _|_|_|    _|  _|_|    _|_|_|      _|_|        _|      _|    _| \n' +
		'  _|    _|  _|        _|    _|    _|    _|        _|      _|      _|    _| \n' +
		'    _|_|    _|          _|_|  _|  _|    _|  _|_|_|        _|        _|_|   \n' +
		'                                                                           \n' +
		'\n' +
		'                                                                               \n' +
		'  _|      _|  _|          _|  _|      _|  _|      _|  _|_|_|_|_|    _|      _| \n' +
		'  _|      _|  _|          _|    _|  _|      _|  _|          _|    _|  _|  _|_| \n' +
		'  _|      _|  _|    _|    _|      _|          _|          _|      _|  _|    _| \n' +
		'    _|  _|      _|  _|  _|      _|  _|        _|        _|        _|  _|    _| \n' +
		'      _|          _|  _|      _|      _|      _|      _|_|_|_|_|    _|      _| \n' +
		'                                                                               \n' +
		'\n' +
		'                                                                         \n' +
		'    _|_|    _|_|_|    _|  _|    _|_|_|_|    _|_|_|  _|_|_|_|_|    _|_|   \n' +
		'  _|    _|        _|  _|  _|    _|        _|                _|  _|    _| \n' +
		'      _|      _|_|    _|_|_|_|  _|_|_|    _|_|_|          _|      _|_|   \n' +
		'    _|            _|      _|          _|  _|    _|      _|      _|    _| \n' +
		'  _|_|_|_|  _|_|_|        _|    _|_|_|      _|_|      _|          _|_|   \n' +
		'                                                                         \n' +
		'\n' +
		'                                                                          \n' +
		'    _|_|    _|  _|_|           _|                                         \n' +
		'  _|    _|  _|      _|         _|                              _|_|_|_|_| \n' +
		'    _|_|_|  _|  _|_|       _|_|_|_|_|  _|_|_|_|_|                         \n' +
		'        _|                     _|                              _|_|_|_|_| \n' +
		'  _|_|_|    _|  _|             _|                  _|_|_|_|_|             \n' +
		'                       _|                                                 \n' +
		'\n' +
		'      _|_|_|_|_|                  _|                              _|  _|   \n' +
		'    _|          _|    _|  _|    _|_|_|  _|_|    _|    _|        _|      _| \n' +
		'  _|    _|_|_|  _|  _|_|_|_|_|  _|_|    _|_|  _|    _|  _|      _|      _| \n' +
		'  _|  _|    _|  _|    _|  _|      _|_|      _|        _|_|  _|  _|      _| \n' +
		'  _|    _|_|_|_|    _|_|_|_|_|  _|_|_|    _|  _|_|  _|    _|    _|      _| \n' +
		'    _|                _|  _|      _|    _|    _|_|    _|_|  _|  _|      _| \n' +
		'      _|_|_|_|_|_|                                                _|  _|   \n' +
		'\n' +
		'                             _|  _|_| \n' +
		'          _|                 _|  _|_| \n' +
		'        _|   _|                       \n' +
		'      _|           _|                 \n' +
		'    _|       _|                       \n' +
		'  _|               _|    _|           \n' +
		'                 _|    _|             \n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font simpleBlock in all colors`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'simpleBlock', '-c', 'red' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  _|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|  _|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  _|  _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  _|  _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  _|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|  _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m               \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|          _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|          _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|  _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|  _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|  _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|  _|  _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|  _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|  _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m               \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|_|_|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|          _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|  _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|    _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|_|_|  _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|  _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  _|    _|  _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|  _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|  _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|_|_|_|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|  _|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|            \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|  _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|    _|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|_|  _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|_|_|_|_|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m         _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m       _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     _|    \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|      \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m_|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|        \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   _|\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m           \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m _|  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m     \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font slick`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'slick' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'╱╭━━━╮╱╭━━╮╱╱╭━━━╮╱╭━━━╮╱╭━━━╮╱╭━━━╮╱╭━━━╮╱╭╮╱╭╮╱╭━━╮╱╱╱╭╮╱╭╮╭━╮╱╭╮╱╱╱╱╭━╮╭━╮╱\n' +
		'╱┃╭━╮┃╱┃╭╮┃╱╱┃╭━╮┃╱╰╮╭╮┃╱┃╭━━╯╱┃╭━━╯╱┃╭━╮┃╱┃┃╱┃┃╱╰┫┣╯╱╱╱┃┃╱┃┃┃╭╯╱┃┃╱╱╱╱┃┃╰╯┃┃╱\n' +
		'╱┃┃╱┃┃╱┃╰╯╰╮╱┃┃╱╰╯╱╱┃┃┃┃╱┃╰━━╮╱┃╰━━╮╱┃┃╱╰╯╱┃╰━╯┃╱╱┃┃╱╱╱╱┃┃╱┃╰╯╯╱╱┃┃╱╱╱╱┃╭╮╭╮┃╱\n' +
		'╱┃╰━╯┃╱┃╭━╮┃╱┃┃╱╭╮╱╱┃┃┃┃╱┃╭━━╯╱┃╭━━╯╱┃┃╭━╮╱┃╭━╮┃╱╱┃┃╱╱╭╮┃┃╱┃╭╮┃╱╱┃┃╱╭╮╱┃┃┃┃┃┃╱\n' +
		'╱┃╭━╮┃╱┃╰━╯┃╱┃╰━╯┃╱╭╯╰╯┃╱┃╰━━╮╱┃┃╱╱╱╱┃╰┻━┃╱┃┃╱┃┃╱╭┫┣╮╱┃╰╯┃╱┃┃┃╰╮╱┃╰━╯┃╱┃┃┃┃┃┃╱\n' +
		'╱╰╯╱╰╯╱╰━━━╯╱╰━━━╯╱╰━━━╯╱╰━━━╯╱╰╯╱╱╱╱╰━━━╯╱╰╯╱╰╯╱╰━━╯╱╰━━╯╱╰╯╰━╯╱╰━━━╯╱╰╯╰╯╰╯╱\n' +
		'\n' +
		'╱╭━╮╱╭╮╱╭━━━╮╱╭━━━╮╱╭━━━╮╱╱╭━━━╮╱╭━━━╮╱╭━━━━╮╱╭╮╱╭╮╱╭╮╱╱╭╮╱╭╮╭╮╭╮╱╭━╮╭━╮╱╭╮╱╱╭╮╱\n' +
		'╱┃┃╰╮┃┃╱┃╭━╮┃╱┃╭━╮┃╱┃╭━╮┃╱╱┃╭━╮┃╱┃╭━╮┃╱┃╭╮╭╮┃╱┃┃╱┃┃╱┃╰╮╭╯┃╱┃┃┃┃┃┃╱╰╮╰╯╭╯╱┃╰╮╭╯┃╱\n' +
		'╱┃╭╮╰╯┃╱┃┃╱┃┃╱┃╰━╯┃╱┃┃╱┃┃╱╱┃╰━╯┃╱┃╰━━╮╱╰╯┃┃╰╯╱┃┃╱┃┃╱╰╮┃┃╭╯╱┃┃┃┃┃┃╱╱╰╮╭╯╱╱╰╮╰╯╭╯╱\n' +
		'╱┃┃╰╮┃┃╱┃┃╱┃┃╱┃╭━━╯╱┃┃╱┃┃╱╱┃╭╮╭╯╱╰━━╮┃╱╱╱┃┃╱╱╱┃┃╱┃┃╱╱┃╰╯┃╱╱┃╰╯╰╯┃╱╱╭╯╰╮╱╱╱╰╮╭╯╱╱\n' +
		'╱┃┃╱┃┃┃╱┃╰━╯┃╱┃┃╱╱╱╱┃╰━╯┃╮╱┃┃┃╰╮╱┃╰━╯┃╱╱╱┃┃╱╱╱┃╰━╯┃╱╱╰╮╭╯╱╱╰╮╭╮╭╯╱╭╯╭╮╰╮╱╱╱┃┃╱╱╱\n' +
		'╱╰╯╱╰━╯╱╰━━━╯╱╰╯╱╱╱╱╰━━━━╯╱╰╯╰━╯╱╰━━━╯╱╱╱╰╯╱╱╱╰━━━╯╱╱╱╰╯╱╱╱╱╰╯╰╯╱╱╰━╯╰━╯╱╱╱╰╯╱╱╱\n' +
		'\n' +
		'╱╭━━━━╮╱╭━━━╮╱╱╭╮╱╱╭━━━╮╱╭━━━╮╱╭╮╱╭╮╱╭━━━╮╱╭━━━╮╱╭━━━╮╱╭━━━╮╱╭━━━╮╱╭╮╱╭━━━╮╱╱╱╱\n' +
		'╱╰━━╮━┃╱┃╭━╮┃╱╭╯┃╱╱┃╭━╮┃╱┃╭━╮┃╱┃┃╱┃┃╱┃╭━━╯╱┃╭━━╯╱┃╭━╮┃╱┃╭━╮┃╱┃╭━╮┃╱┃┃╱┃╭━╮┃╱╱╱╱\n' +
		'╱╱╱╭╯╭╯╱┃┃┃┃┃╱╰╮┃╱╱╰╯╭╯┃╱╰╯╭╯┃╱┃╰━╯┃╱┃╰━━╮╱┃╰━━╮╱╰╯╭╯┃╱┃╰━╯┃╱┃╰━╯┃╱┃┃╱╰╯╭╯┃╱╱╱╱\n' +
		'╱╱╭╯╭╯╱╱┃┃┃┃┃╱╱┃┃╱╱╭━╯╭╯╱╭╮╰╮┃╱╰━━╮┃╱╰━━╮┃╱┃╭━╮┃╱╱╱┃╭╯╱┃╭━╮┃╱╰━━╮┃╱╰╯╱╱╱┃╭╯╱╱╱╱\n' +
		'╱╭╯━╰━╮╱┃╰━╯┃╱╭╯╰╮╱┃╰━━╮╱┃╰━╯┃╱╱╱╱┃┃╱╭━━╯┃╱┃╰━╯┃╱╱╱┃┃╱╱┃╰━╯┃╱╭━━╯┃╱╭╮╱╱╱╭╮╱╱╭╮╱\n' +
		'╱╰━━━━╯╱╰━━━╯╱╰━━╯╱╰━━━╯╱╰━━━╯╱╱╱╱╰╯╱╰━━━╯╱╰━━━╯╱╱╱╰╯╱╱╰━━━╯╱╰━━━╯╱╰╯╱╱╱╰╯╱╱╰╯╱\n' +
		'\n' +
		'╱╱╱╱╱╱╱╱╱╱╱╱╱╱╱╱╱╱╱╱╱╱╭━━━━╮╱╱╱╭━━╮╱╱╱╱╭╮╱╱╭╮╱╱╭━╮╱╱╭━━╮╱╱╱╭━╮╱╭━╮╱╱╱╱╱╱╱╭━╮╱╱╱╱\n' +
		'╱╱╱╱╱╱╱╱╱╱╱╱╱╱╱╱╱╱╱╱╱╱┃╭━━╮┃╱╱╭╯╭╮╰╮╱╭━╯╰╮╱╰╯╱╭╯╭╯╱╱┃╭━╯╱╱╭╯╭╯╱╰╮╰╮╱╱╱╱╱╭╯╭╯╱╭╮╱\n' +
		'╱╱╭╮╱╱╱╱╱╱╱╱╱╱╱╱╭━━━╮╱┃┃╭━┃┃╱╱╰╮┃┃╭╯╱┃╰━━╮╱╱╱╭╯╭╯╱╱╭╯╰╮╱╱╭╯╭╯╱╱╱╰╮╰╮╱╱╱╭╯╭╯╱╱╰╯╱\n' +
		'╱╭╯╰╮╱╭━━╮╱╱╱╱╱╱╰━━━╯╱┃┃╰╯┃┃╱╱╭╯┃┃╰╮╱╰━━╮┃╱╱╭╯╭╯╱╱╱┃╭╮┃╱╱╰╮╰╮╱╱╱╭╯╭╯╱╱╭╯╭╯╱╱╱╭╮╱\n' +
		'╱╰╮╭╯╱╰━━╯╱╭━━╮╱╭━━━╮╱┃╰━━╯━╮╱╰╮╰╯╭╯╱╰╮╭━╯╱╭╯╭╯╱╭╮╱┃╰╯┃╮╱╱╰╮╰╮╱╭╯╭╯╱╱╭╯╭╯╱╱╱╱╰╯╱\n' +
		'╱╱╰╯╱╱╱╱╱╱╱╰━━╯╱╰━━━╯╱╰━━━━━╯╱╱╰━━╯╱╱╱╰╯╱╱╱╰━╯╱╱╰╯╱╰━━━╯╱╱╱╰━╯╱╰━╯╱╱╱╰━╯╱╱╱╱╱╱╱╱\n' +
		'\n' +
		'╱╭╮╱╱╱╱╭╮╱╭╮╭╮╱\n' +
		'╱┃┃╱╱╱╱╰╯╱╰╯╰╯╱\n' +
		'╱╰╯╱╱╱╱╱╱╱╱╱╱╱╱\n' +
		'╱╭╮╱╭╮╱╱╱╱╱╱╱╱╱\n' +
		'╱╰┫╱╰┫╱╱╱╱╱╱╱╱╱\n' +
		'╱╱╯╱╱╯╱╱╱╱╱╱╱╱╱\n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font slick in all colors`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'slick', '-c', 'red,green' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮╭━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━╮╭━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╮╭╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰┫┣╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃┃╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃╰╯┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰╯╰╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰╯╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭╮╭╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃╭━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃┃┃┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯╰╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰┻━┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭┫┣╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃┃╰╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃┃┃┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯╰━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯╰╯╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮╭╮╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━╮╭━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃╰╮┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭╮╭╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰╮╭╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃┃┃┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╮╰╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰╮╭╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭╮╰╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯┃┃╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╮┃┃╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃┃┃┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╮╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╮╰╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃╰╮┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭╮╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰╯╰╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯╰╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╮╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃┃╰╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╮╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╮╭╮╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯╭╮╰╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯╰━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━╯╰━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━╮━┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m╭╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃┃┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯╭╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯╭╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯╭╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯╭╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃┃┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮╰╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m┃╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m┃╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯━╰━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯╰╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━╯┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m╭━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m╭━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━╮\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱\u001b[39m\u001b[38;2;255;0;0m╭━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯╭╮╰╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━╯╰╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╮╰╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱\u001b[39m\u001b[38;2;255;0;0m╭╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃╭━┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╮┃┃╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m╭╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯╰╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╮╰╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m╭╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯╰╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃╰╯┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯┃┃╰╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╭╮┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╮╰╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╮╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭━━━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰━━╯━╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╮╰╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╮╭━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃╰╯┃╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╮╰╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╯╭╯\u001b[39m\u001b[38;2;0;128;0m╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━╯\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━━━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;255;0;0m╰━╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━╯\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰━╯\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╭╮\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰┫\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╰┫\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;255;0;0m╯\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\u001b[38;2;0;128;0m╱╱╱╱\u001b[39m\u001b[38;2;0;128;0m╱\u001b[39m\n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font pallet`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'pallet' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'─╔═══╗─╔══╗──╔═══╗─╔═══╗─╔═══╗─╔═══╗─╔═══╗─╔╗─╔╗─╔══╗───╔╗─╔╗╔═╗─╔╗────╔═╗╔═╗─\n' +
		'─║╔═╗║─║╔╗║──║╔═╗║─╚╗╔╗║─║╔══╝─║╔══╝─║╔═╗║─║║─║║─╚╣╠╝───║║─║║║╔╝─║║────║║╚╝║║─\n' +
		'─║║─║║─║╚╝╚╗─║║─╚╝──║║║║─║╚══╗─║╚══╗─║║─╚╝─║╚═╝║──║║────║║─║╚╝╝──║║────║╔╗╔╗║─\n' +
		'─║╚═╝║─║╔═╗║─║║─╔╗──║║║║─║╔══╝─║╔══╝─║║╔═╗─║╔═╗║──║║──╔╗║║─║╔╗║──║║─╔╗─║║║║║║─\n' +
		'─║╔═╗║─║╚═╝║─║╚═╝║─╔╝╚╝║─║╚══╗─║║────║╚╩═║─║║─║║─╔╣╠╗─║╚╝║─║║║╚╗─║╚═╝║─║║║║║║─\n' +
		'─╚╝─╚╝─╚═══╝─╚═══╝─╚═══╝─╚═══╝─╚╝────╚═══╝─╚╝─╚╝─╚══╝─╚══╝─╚╝╚═╝─╚═══╝─╚╝╚╝╚╝─\n' +
		'\n' +
		'─╔═╗─╔╗─╔═══╗─╔═══╗─╔═══╗──╔═══╗─╔═══╗─╔════╗─╔╗─╔╗─╔╗──╔╗─╔╗╔╗╔╗─╔═╗╔═╗─╔╗──╔╗─\n' +
		'─║║╚╗║║─║╔═╗║─║╔═╗║─║╔═╗║──║╔═╗║─║╔═╗║─║╔╗╔╗║─║║─║║─║╚╗╔╝║─║║║║║║─╚╗╚╝╔╝─║╚╗╔╝║─\n' +
		'─║╔╗╚╝║─║║─║║─║╚═╝║─║║─║║──║╚═╝║─║╚══╗─╚╝║║╚╝─║║─║║─╚╗║║╔╝─║║║║║║──╚╗╔╝──╚╗╚╝╔╝─\n' +
		'─║║╚╗║║─║║─║║─║╔══╝─║║─║║──║╔╗╔╝─╚══╗║───║║───║║─║║──║╚╝║──║╚╝╚╝║──╔╝╚╗───╚╗╔╝──\n' +
		'─║║─║║║─║╚═╝║─║║────║╚═╝╠╗─║║║╚╗─║╚═╝║───║║───║╚═╝║──╚╗╔╝──╚╗╔╗╔╝─╔╝╔╗╚╗───║║───\n' +
		'─╚╝─╚═╝─╚═══╝─╚╝────╚════╝─╚╝╚═╝─╚═══╝───╚╝───╚═══╝───╚╝────╚╝╚╝──╚═╝╚═╝───╚╝───\n' +
		'\n' +
		'─╔════╗─╔═══╗──╔╗──╔═══╗─╔═══╗─╔╗─╔╗─╔═══╗─╔═══╗─╔═══╗─╔═══╗─╔═══╗─╔╗─╔═══╗────\n' +
		'─╚══╗═║─║╔═╗║─╔╝║──║╔═╗║─║╔═╗║─║║─║║─║╔══╝─║╔══╝─║╔═╗║─║╔═╗║─║╔═╗║─║║─║╔═╗║────\n' +
		'───╔╝╔╝─║║║║║─╚╗║──╚╝╔╝║─╚╝╔╝║─║╚═╝║─║╚══╗─║╚══╗─╚╝╔╝║─║╚═╝║─║╚═╝║─║║─╚╝╔╝║────\n' +
		'──╔╝╔╝──║║║║║──║║──╔═╝╔╝─╔╗╚╗║─╚══╗║─╚══╗║─║╔═╗║───║╔╝─║╔═╗║─╚══╗║─╚╝───║╔╝────\n' +
		'─╔╝═╚═╗─║╚═╝║─╔╝╚╗─║║╚═╗─║╚═╝║────║║─╔══╝║─║╚═╝║───║║──║╚═╝║─╔══╝║─╔╗───╔╗──╔╗─\n' +
		'─╚════╝─╚═══╝─╚══╝─╚═══╝─╚═══╝────╚╝─╚═══╝─╚═══╝───╚╝──╚═══╝─╚═══╝─╚╝───╚╝──╚╝─\n' +
		'\n' +
		'──────────────────────╔════╗───╔╩╩╩╗──╔╝╩╚╗─╔╗──╔═╗───╔╗────╔═╗─╔═╗───────╔═╗─\n' +
		'────────────────╔═══╗─║╔══╗║──╔╝╔═╗╚╗─║╔═╗║─╚╝─╔╝╔╝───║║───╔╝╔╝─╚╗╚╗─────╔╝╔╝─\n' +
		'──╔╗──╔══╗──────╚═══╝─║║╔═║║──╚╗╠═╣╔╝─║╚══╗───╔╝╔╝──╔═╝╚╗─╔╝╔╝───╚╗╚╗───╔╝╔╝──\n' +
		'─╔╝╚╗─╚══╝──────╔═══╗─║║╚╝║║──╔╝╠═╣╚╗─╚══╗║──╔╝╔╝───║╔╗╔╝─╚╗╚╗───╔╝╔╝──╔╝╔╝───\n' +
		'─╚╗╔╝──────╔══╗─╚═══╝─║╚══╝╠╗─╚╗╚═╝╔╝─║╚═╝║─╔╝╔╝─╔╗─║╚╝║───╚╗╚╗─╔╝╔╝──╔╝╔╝────\n' +
		'──╚╝───────╚══╝───────╚═════╝──╚╦╦╦╝──╚╗╦╔╝─╚═╝──╚╝─╚══╝────╚═╝─╚═╝───╚═╝─────\n' +
		'\n' +
		'───────╔╗─╔╗─╔╗╔╗─\n' +
		'─╔╗────║║─║║─║║║║─\n' +
		'─╚╝────╚╝─╚╝─╚╝╚╝─\n' +
		'─╔╗─╔╗─╔╗─────────\n' +
		'─╚╝─╚╣─╚╣─────────\n' +
		'─────╝──╝─────────\n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font pallet in all colors`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'pallet', '-c', 'red,blue,green' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗╔═╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m───\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═╗╔═╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╗╔╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╣╠╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║║╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m───\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║╚╝║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚╝╚╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚╝╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m───\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔╗╔╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║╔═╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║║║║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╚╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m───\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚╩═║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╣╠╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║║╚╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║║║║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m───\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝╚═╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝╚╝╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔════╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗╔╗╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═╗╔═╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║╚╗║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔╗╔╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚╗╔╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║║║║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╗╚╝╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚╗╔╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔╗╚╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝║║╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╗║║╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║║║║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╗╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╗╚╝╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║╚╗║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔╗╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚══╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚╝╚╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╚╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╗╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m───\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝╠╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║║╚╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╗╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╗╔╗╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╔╗╚╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m───\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚════╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝╚═╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═╝╚═╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔════╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚══╗═║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m╔╝╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║║║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝╔╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝╔╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝╔╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝╔╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║║║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═╝╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗╚╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚══╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚══╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m║╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚══╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m║╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝═╚═╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╚╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║╚═╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m───\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔══╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔══╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚════╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m───\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m────\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m────\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m────\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─────\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔════╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╩╩╩╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╩╚╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m╔═╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m╔═╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═╗\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m────\u001b[39m\u001b[38;2;255;0;0m╔═╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m────\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m────\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m────\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔══╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╔═╗╚╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔═╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╗╚╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m───\u001b[39m\u001b[38;2;255;0;0m╔╝╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m────\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║╔═║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╗╠═╣╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m╔╝╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═╝╚╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╗╚╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m╔╝╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╚╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m────\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔═══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║╚╝║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╠═╣╚╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚══╗║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╔╝\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╔╗╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╗╚╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╔╝\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╗╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m────\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔══╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚══╝╠╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╗╚═╝╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚═╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║╚╝║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╗╚╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╝╔╝\u001b[39m\u001b[38;2;0;0;255m───\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m────\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─────\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═════╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╦╦╦╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╗╦╔╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═╝\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚══╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;255;0;0m╚═╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═╝\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚═╝\u001b[39m\u001b[38;2;0;0;255m────\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m║║║║\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╔╗\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m────\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╣\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╚╣\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m────\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;255;0;0m╝\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m──\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\u001b[38;2;0;0;255m────\u001b[39m\u001b[38;2;0;0;255m─\u001b[39m\n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font grid`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'grid' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'╋╋╋╋╋╋┏┓╋╋╋╋╋╋╋╋╋╋┏┓╋╋╋╋╋╋╋┏━┓╋╋╋╋╋╋┏┓╋╋╋┏┓╋╋┏┓╋┏┓╋╋╋┏┓╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋\n' +
		'╋┏━━┓╋┃┗━┓╋┏━━┓╋┏━┛┃╋┏━━┓╋┏┛┗┓╋┏━━┓╋┃┗━┓╋┗┛╋╋┗┛╋┃┃┏┓╋┃┃╋╋┏┓┏┓╋┏━┓╋╋┏━━┓╋┏━━┓╋\n' +
		'╋┃┏┓┃╋┃┏┓┃╋┃┏━┛╋┃┏┓┃╋┃┃━┫╋┗┓┏┛╋┃┏┓┃╋┃┏┓┃╋┏┓╋╋┏┓╋┃┗┛┛╋┃┃╋╋┃┗┛┃╋┃┏┓┓╋┃┏┓┃╋┃┏┓┃╋\n' +
		'╋┃┏┓┃╋┃┗┛┃╋┃┗━┓╋┃┗┛┃╋┃┃━┫╋╋┃┃╋╋┃┗┛┃╋┃┃┃┃╋┃┃╋╋┃┃╋┃┏┓┓╋┃┗┓╋┃┃┃┃╋┃┃┃┃╋┃┗┛┃╋┃┗┛┃╋\n' +
		'╋┗┛┗┛╋┗━━┛╋┗━━┛╋┗━━┛╋┗━━┛╋╋┗┛╋╋┗━┓┃╋┗┛┗┛╋┗┛╋┏┛┃╋┗┛┗┛╋┗━┛╋┗┻┻┛╋┗┛┗┛╋┗━━┛╋┃┏━┛╋\n' +
		'╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋┗━━┛╋╋╋╋╋╋╋╋╋┗━┛╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋┗┛╋╋╋\n' +
		'\n' +
		'╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋┏┓╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋┏━━━┓╋╋┏┓╋╋┏━━━┓╋┏━━━┓╋\n' +
		'╋┏━━┓╋┏━┓╋┏━━┓╋┏┛┗┓╋┏┓┏┓╋┏┓┏┓╋┏┓┏┓┏┓╋┏┓┏┓╋┏┓╋┏┓╋┏━━━┓╋┃┏━┓┃╋┏┛┃╋╋┃┏━┓┃╋┃┏━┓┃╋\n' +
		'╋┃┏┓┃╋┃┏┛╋┃━━┫╋┗┓┏┛╋┃┃┃┃╋┃┗┛┃╋┃┗┛┗┛┃╋┗╋╋┛╋┃┗━┛┃╋┣━━┃┃╋┃┃┃┃┃╋┗┓┃╋╋┗┛┏┛┃╋┗┛┏┛┃╋\n' +
		'╋┃┗┛┃╋┃┃╋╋┣━━┃╋╋┃┗┓╋┃┗┛┃╋┗┓┏┛╋┗┓┏┓┏┛╋┏╋╋┓╋┗━┓┏┛╋┃┃━━┫╋┃┃┃┃┃╋╋┃┃╋╋┏━┛┏┛╋┏┓┗┓┃╋\n' +
		'╋┗━┓┃╋┗┛╋╋┗━━┛╋╋┗━┛╋┗━━┛╋╋┗┛╋╋╋┗┛┗┛╋╋┗┛┗┛╋┗━━┛╋╋┗━━━┛╋┃┗━┛┃╋┏┛┗┓╋┃┗━┻┓╋┃┗━┛┃╋\n' +
		'╋╋╋┗┛╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋┗━━━┛╋┗━━┛╋┗━━━┛╋┗━━━┛╋\n' +
		'\n' +
		'╋┏┓╋┏┓╋┏━━━┓╋┏━━━┓╋┏━━━┓╋┏━━━┓╋┏━━━┓╋┏┓╋┏━━━┓╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋┏━━━━┓╋╋\n' +
		'╋┃┃╋┃┃╋┃┏━━┛╋┃┏━━┛╋┃┏━┓┃╋┃┏━┓┃╋┃┏━┓┃╋┃┃╋┃┏━┓┃╋╋╋╋╋┏┓╋╋╋╋╋╋╋╋╋╋╋╋┏━━━┓╋┃┏━━┓┃╋╋\n' +
		'╋┃┗━┛┃╋┃┗━━┓╋┃┗━━┓╋┗┛┏┛┃╋┃┗━┛┃╋┃┗━┛┃╋┃┃╋┗┛┏┛┃╋╋╋╋┏┛┗┓╋┏━━┓╋╋╋╋╋╋┗━━━┛╋┃┃┏━┃┃╋╋\n' +
		'╋┗━━┓┃╋┗━━┓┃╋┃┏━┓┃╋╋╋┃┏┛╋┃┏━┓┃╋┗━━┓┃╋┗┛╋╋╋┃┏┛╋╋╋╋┗┓┏┛╋┗━━┛╋╋╋╋╋╋┏━━━┓╋┃┃┗┛┃┃╋╋\n' +
		'╋╋╋╋┃┃╋┏━━┛┃╋┃┗━┛┃╋╋╋┃┃╋╋┃┗━┛┃╋┏━━┛┃╋┏┓╋╋╋┏┓╋╋┏┓╋╋┗┛╋╋╋╋╋╋╋┏━━┓╋┗━━━┛╋┃┗━━┛┗┓╋\n' +
		'╋╋╋╋┗┛╋┗━━━┛╋┗━━━┛╋╋╋┗┛╋╋┗━━━┛╋┗━━━┛╋┗┛╋╋╋┗┛╋╋┗┛╋╋╋╋╋╋╋╋╋╋╋┗━━┛╋╋╋╋╋╋╋┗━━━━━┛╋\n' +
		'\n' +
		'╋╋┏━━━┓╋╋╋┏┓╋╋┏┓╋╋┏━┓╋╋╋┏┓╋╋╋╋┏━┓╋┏━┓╋╋╋╋╋╋╋┏━┓╋╋╋╋╋╋╋╋╋╋┏┓╋┏┓┏┓╋\n' +
		'╋┏┛┏━┓┗┓╋┏┛┗┓╋┗┛╋┏┛┏┛╋╋╋┃┃╋╋╋┏┛┏┛╋┗┓┗┓╋╋╋╋╋┏┛┏┛╋┏┓╋┏┓╋╋╋╋┗┛╋┗┛┗┛╋\n' +
		'╋┗┓┃┃┃┏┛╋┃━━┫╋╋╋┏┛┏┛╋╋┏━┛┗┓╋┏┛┏┛╋╋╋┗┓┗┓╋╋╋┏┛┏┛╋╋┗┛╋┗┛╋╋╋╋╋╋╋╋╋╋╋╋\n' +
		'╋┏┛┃┃┃┗┓╋┣━━┃╋╋┏┛┏┛╋╋╋┃┏┓┏┛╋┗┓┗┓╋╋╋┏┛┏┛╋╋┏┛┏┛╋╋╋┏┓╋╋╋╋╋╋╋╋╋╋╋╋╋╋╋\n' +
		'╋┗┓┗━┛┏┛╋┗┓┏┛╋┏┛┏┛╋┏┓╋┃┗┛┃╋╋╋┗┓┗┓╋┏┛┏┛╋╋┏┛┏┛╋╋╋╋┗┛╋┏┓╋┏┓╋╋╋╋╋╋╋╋╋\n' +
		'╋╋┗━━━┛╋╋╋┗┛╋╋┗━┛╋╋┗┛╋┗━━┛╋╋╋╋┗━┛╋┗━┛╋╋╋┗━┛╋╋╋╋╋╋╋╋┗┫╋┗┫╋╋╋╋╋╋╋╋╋\n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font grid in all colors`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'grid', '-c', 'red,blue,green' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┗┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃━┫\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┓┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗┛┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏┓┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃━┫\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏┓┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┻┻┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┗┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓┏┓┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏━┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏━┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏━┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃━━┫\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┓┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗┛┗┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗╋╋┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗━┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┣━━┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃┃┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛┏┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛┏┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┣━━┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┓┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┓┏┓┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏╋╋┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━┓┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃━━┫\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃┃┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━┛┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓┗┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗━┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┗┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗━┻┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗━┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏━┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏━┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏━┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏━┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏━━┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗━┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛┏┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗━┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗━┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛┏┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┗┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃┏━┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏━┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;255;0;0m┃┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏━┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━┓┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;255;0;0m┃┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┓┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┃┗┛┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗━┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗━┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗━━┛┗┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━━━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━━━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;255;0;0m┏━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;255;0;0m┏━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━┓\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;255;0;0m┏━┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┏━┓┗┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┗┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;255;0;0m┃┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┓┗┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋\u001b[39m\u001b[38;2;255;0;0m┏┛┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┓┃┃┃┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃━━┫\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;255;0;0m┏┛┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏━┛┗┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┓┗┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;255;0;0m┏┛┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┃┃┃┗┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┣━━┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┏┛\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┏┓┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┓┗┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┏┛\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┓┗━┛┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┓┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┃┗┛┃\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┓┗┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┏┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┛┏┛\u001b[39m\u001b[38;2;0;0;255m╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┏┓\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━┛\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;255;0;0m┗┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;255;0;0m┗━┛\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━┛\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗━┛\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┫\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;255;0;0m┗┫\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\u001b[38;2;0;0;255m╋╋╋╋\u001b[39m\u001b[38;2;0;0;255m╋\u001b[39m\n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font tiny`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'tiny' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		' ▄▀█ █▄▄ █▀▀ █▀▄ █▀▀ █▀▀ █▀▀ █ █ █   █ █▄▀ █   █▀▄▀█ █▄ █ █▀█ █▀█ █▀█ █▀█ █▀▀ \n' +
		' █▀█ █▄█ █▄▄ █▄▀ ██▄ █▀  █▄█ █▀█ █ █▄█ █ █ █▄▄ █ ▀ █ █ ▀█ █▄█ █▀▀ ▀▀█ █▀▄ ▄▄█ \n' +
		'\n' +
		' ▀█▀ █ █ █ █ █ █ █ ▀▄▀ █▄█ ▀█ ▞█▚ ▄█ ▀█ ▀▀█ █ █ █▀ █▄▄ ▀▀█ ███ █▀█ █ ▀█   ▄█▄ \n' +
		'  █  █▄█ ▀▄▀ ▀▄▀▄▀ █ █  █  █▄ ▚█▞  █ █▄ ▄██ ▀▀█ ▄█ █▄█   █ █▄█ ▀▀█ ▄  ▄ ▄  ▀  \n' +
		'\n' +
		' ▄▄    ▀▀ ▛█▜ ▟▄▙ ▖█▗ ▀ ▄▀ ▄▄█ ▄▀ ▀▄   ▄▀ ▀      ▀ ▛ ▜ \n' +
		'    ▄▄ ▀▀ ▙▟▃ ▜▀▛ ▘█▝ ▄▀ ▄ █▄█ ▀▄ ▄▀ ▄▀   ▄ ▄▀ █       \n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});


test(`Fonts - Will output all characters for font tiny in all colors`, () => {
	const output = Spawn(
		'node',
		[ path.normalize(`${__dirname }/../../bin/index.js`), supportedCharacters, '-f', 'tiny', '-c', 'red' ],
		{
			encoding : 'utf8',
			env: { ...process.env },
		}
	);

	const expected = '' +
		'\n\n' +
		'\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▄▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█ █\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  █\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀▄▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄ █\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m██▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█ █\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█ ▀ █\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█ ▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▄▄█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀█▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█ █\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█ █\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█ █ █\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀▄▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▞█▚\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▄█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█ █\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m███\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▄█▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m █ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀▄▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀▄▀▄▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█ █\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m █ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▚█▞\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m █\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▄██\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▄█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  █\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀▀█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m ▀ \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▄▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▛█▜\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▟▄▙\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▖█▗\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀ ▄▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▄▄█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▄▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  ▄▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▛ ▜\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▄▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▙▟▃\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▜▀▛\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▘█▝\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▄▀ ▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█▄█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▀▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▄▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▄▀  \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▄\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m▄▀\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m█\u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\u001b[38;2;255;0;0m   \u001b[39m\u001b[38;2;255;0;0m \u001b[39m\n' +
		'\n\n';

	expect( inspect( output.stdout ) ).toBe( inspect( expected ) );
	expect( output.stderr ).toBe( '' );
});
